<?php
 /*---------------------------------------------------------------------------
 *	mstw-lm-league-schedule-slider-class.php
 *	Contains the class for the MSTW League Manager League Schedule Slider
 *  shortcode [mstw_league_schedule_slider]
 *
 *	MSTW Wordpress Plugins (http://shoalsummitsolutions.com)
 *	Copyright 2016-19 Mark O'Donnell (mark@shoalsummitsolutions.com)
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.

 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 *-------------------------------------------------------------------------*/

class MSTW_LEAGUE_SCHEDULE_SLIDER {
	
	public function __construct( ) {
		add_filter( 'get_league_schedule_slider_instance', [$this, 'get_instance'] );
	}
	
	public function get_instance( ) {
		return $this; //return the object
	}
	
	//
	// Handles the shortcode inline arguments and merges them with options DB
	//
	public function league_schedule_slider_handler( $atts, $content = null, $shortcode ) {
		//mstw_log_msg( "MSTW_LEAGUE_SCHEDULE_SLIDER:league_schedule_slider_handler: shortcode= $shortcode " );
		//mstw_log_msg( 'shortcode: ' . $shortcode );
		//mstw_log_msg( 'plugin slug 1: ' . plugin_dir_path( __FILE__ ) );
		
		/*if ( !array_key_exists( 'league', $atts ) ) {
			return ( '<h3 class="mstw-lm-user-msg">' . sprintf( __( 'A valid league argument must be provided for shortcode %s.', 'mstw-league-manager' ), $shortcode ) . '</h3>' );
		}
		*/
		
		// get the options set in the admin settings screen
		if ( 'mstw_league_schedule_slider' == $shortcode ) {
			$args = mstw_lm_get_slider_defaults( );
			
		} else if ( 'mstw_league_schedule_ticker' == $shortcode ) {
			$args = mstw_lm_get_ticker_defaults( );
			
		} else {
			mstw_log_msg( "Unknown shortcode $shorcode . This should not happen." );
			$args = array();
			
		}
		
		// show_final_only is a late-comer added for VSN
		if ( !array_key_exists( 'show_final_only', $args ) ) {
			$args['show_final_only'] = 0;	
		}
		
		//Need to do this to grap the sport winner = high/low setting
		$winner = 'high';
		if ( array_key_exists( 'league', $atts ) ) {
			$league_slugs = explode( ',', $atts['league'] );
			$sport_slug = mstw_lm_get_league_sport( $league_slugs[0] );
			$sport_opts = mstw_lm_get_sport_options( $sport_slug );
			//mstw_log_msg( "options for sport $sport_slug" );
			//mstw_log_msg( $sport_opts );
			$winner = mstw_safe_get( 'winner', $sport_opts, 'high' );
		}
		
		$args['winner'] = $winner;	

		// slider_status_link is a late-comer added for SCS
		$slider_status_link = mstw_safe_get( 'slider_status_link', $args, 'none' );
		$args['slider_status_link'] = $slider_status_link;
		
		// ticker_status_link is a late-comer added for SCS
		$ticker_status_link = mstw_safe_get( 'ticker_status_link', $args, 'none' );
		$args['ticker_status_link'] = $ticker_status_link;
		
		// then merge the parameters passed to the shortcode 
		$attribs = shortcode_atts( $args, $atts );
		//mstw_log_msg( "Merged args & settings");
		//mstw_log_msg( $attribs );
		
		$games = $this -> build_games_list( $attribs );
		//mstw_log_msg( "Number of games found: " . count( $games ) );
		
		if ( $games ) {
			return $this -> build_shortcode( $shortcode, $attribs, $games );
			
		} else {
			return ( '<h3 class="mstw-lm-user-msg">' . sprintf( __( 'No games found for specified league(s): %s & season(s): %s.', 'mstw-league-manager' ), $attribs['league'], $attribs['season' ] ) . '</h3>' );
		}
		
		
	} //End: league_schedule_slider_handler( )
	
	//-----------------------------------------------------------------------------
	// build_games_list - Builds the list of games based on the slider atts 
	// 	Called from league_schedule_slider_handler( ) after it has processed 
	//	the arguments & settings
	//
	// ARGUMENTS
	// 	$atts  - the plugin settings and shortcode arguments
	//
	// RETURNS
	//	A list of games based on the provided atts, or null if there's a problem
	//
	function build_games_list( $atts ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_games_list:' );
		//mstw_log_msg( '$atts:' );
		//mstw_log_msg( $atts );
		
		//
		// If there's no league slugs, we now (v 2.1) show all games in the season(s)
		//
		$league_slugs = mstw_safe_get( 'league', $atts, '' );
		
		$league_slugs = ( $league_slugs ) ? explode( ',', $atts['league'] ) : '';
		//$league_slugs = explode( ',', $atts['league'] );
		//mstw_log_msg( 'league slug = ' . $league_slugs[0] );
		//mstw_log_msg( $league_slugs );
		
		$season_slugs = explode( ',', $atts['season'] );
		//mstw_log_msg( '$season_slugs:' ) ;
		//mstw_log_msg( $season_slugs );
		
		//		
		// Have to have a season. If not, default to current year.
		//
		if ( !$season_slugs ) {
			$season_slugs[0] = date( 'Y' );
		}
		
		//
		// HANDLE THE TIME OPTIONS
		//  Have to have a first_dtg, create one if necessary
		//
		//	*if first_dtg is 'now', use the current time
		//		* if there's any problem with first_dtg, set it to 0
		//		
		//	*if interval_days is set, get posts 
		//		between first_dtg - interval_days and first_dtg + interval_days
		//
		//  *elseif last_dtg is set
		//		get posts between first and last
		//		if there's a problem with last_dtg, set it to PHP_INT_MAX
		//
		
		if ( 'now' == $atts['first_dtg'] ) {
			$first_dtg = current_time( 'timestamp' );
			
		} else {
			$first_dtg = strtotime( $atts['first_dtg'] );
			
		} 
		
		if ( false === $first_dtg || $first_dtg < 0 ) {
			$first_dtg = 1;
		}
		
		$base_dtg  = $first_dtg;
		
		if ( $interval_days = $atts['interval_days'] ) {
			if ( is_numeric( $interval_days ) ) {
				$first_dtg = $base_dtg - $interval_days * DAY_IN_SECONDS;
				$last_dtg  = $base_dtg + $interval_days * DAY_IN_SECONDS;
				$first_dtg = ( $first_dtg < 1 ) ? 1 : $first_dtg;
				$last_dtg  = ( $last_dtg > PHP_INT_MAX ) ? PHP_INT_MAX : $last_dtg;
				
			} else {
				$last_dtg = PHP_INT_MAX;
				mstw_log_msg( "MSTW_LEAGUE_SCHEDULE_SLIDER.build_games_list: interval_days is not numeric." );
				
			}	
			
		} else {
			$last_dtg = strtotime( $atts['last_dtg'] );
			if ( false === $last_dtg || $last_dtg <= $first_dtg ) {
				$last_dtg = PHP_INT_MAX;
			}
			
		} //End: if ( $interval_days = $atts['interval_days'] ) 
			
		/*
		 * DEBUG CODE
		 
		if ( isset( $base_dtg ) ) {
			mstw_log_msg( "base_dtg: $base_dtg" );
			mstw_log_msg( "base_dtg: " . date( 'Y-m-d', $base_dtg ) );
		}
		if ( isset( $first_dtg ) ) {
			mstw_log_msg( "first_dtg: $first_dtg" );
			mstw_log_msg( "first_dtg: " . date( 'Y-m-d', $first_dtg ) );
		}
		if ( isset( $last_dtg ) ) {
			mstw_log_msg( "last_timestamp: $last_dtg" );
			mstw_log_msg( "last_dtg: " . date( 'Y-m-d', $last_dtg ) );
		}
		if ( isset( $interval_days ) ) {
			mstw_log_msg( "interval_days: $interval_days" );
		}
		
		*/
				
		// Right now, this ain't going to change; 
		// it was for last_dtg == now in MSTW Schedules & Scoreboards
		$sort_order = 'ASC';
		
		$meta_query = array( 
						array( 'key'     => 'game_season',
									 'value'   => $season_slugs, //$season_slugs[0],
									 'compare' => 'IN', //'=',
									),
						array(
									 'key'     => 'game_unix_dtg',
									 'value'   => array( $first_dtg, $last_dtg ),
									 'type'    => 'NUMERIC',
									 'compare' => 'BETWEEN'
								 )	 
						);
		
		//
		// All games, including non-league games are displayed by default
		//
		$show_nonleague = mstw_safe_get( 'show_nonleague', $atts, 1 );
		
		if ( !$show_nonleague ) { //show league game only
		
			$nonleague_arg = array( 'key'  => 'game_nonleague',
															'value'   => 0,
															'compare' => '=',
														);
											
			$meta_query[] = $nonleague_arg;
			
		}
		
		//
		// Show only games that are final - added for VSN Oct 2017
		//
		$show_final_only = mstw_safe_get( 'show_final_only', $atts, 0 );
		
		if ( $show_final_only ) { //show games that are final only
			
			$is_final_arg = array( 'key' => 'game_is_final',
									     'value'   => 1,
									     'compare' => '=',
									    );
											
			$meta_query[] = $is_final_arg;
			
		}
		
		//
		// No league arg means grab ALL games from the specified season
		// Added in 2.1 for SCS (home page)
		//
		if ( $league_slugs ) {
			$tax_query = array(
												array( 
												'taxonomy' => 'mstw_lm_league',
												'field'    => 'slug',
												'terms'    => $league_slugs,
												'operator' => 'IN'
												),
						           );
			
		} else {
			// pull games from all the leagus
			$tax_query = '';
		}
		
		// Get the games posts
		$games = get_posts( 
					array( 'numberposts' => -1,
						     'post_type'   => 'mstw_lm_game',
								 'tax_query'   => $tax_query,
									'meta_query'  => $meta_query,					
									'orderby' => 'meta_value', 
									'meta_key' => 'game_unix_dtg',
									'orderby' => 'meta_value_num',
									'order' => $sort_order 
								) 
							);						
		
		return $games;

	} //End: build_games_list( )	
	
	//-----------------------------------------------------------------------------
	// build_shortcode - processes arguments and returns shortcode HTML
	// 	
	// ARGUMENTS
	//	$shortcode - the shortcode being called
	// 	$atts  - the plugin settings and shortcode arguments
	//	$games - the list of games already built based on the shortcode args
	//
	// RETURNS
	//	HTML for the schedule slider as a string
	//
	function build_shortcode( $shortcode, $atts, $games ) { 
		//mstw_log_msg( "MSTW_LEAGUE_SCHEDULE_SLIDER.build_shortcode: $shortcode" );
		//mstw_log_msg( 'attributes passed to build_shortcode' );
		//mstw_log_msg( $atts );
		
		// This has already been checked, but what the heck
		if ( !$games ) {
			return ( '<h3 class="mstw-lm-user-msg">' . __( 'No games found for specified league(s) & season(s).', 'mstw-league-manager' ) . '</h3>' );
		}
		
		$nbr_of_games = count( $games );
			
		// find the next game
		$next_game = $this -> get_next_game( $games, current_time( 'timestamp' ) - DAY_IN_SECONDS );
		$next_game_number = $next_game['number'];
		$next_game_id     = $next_game['id'];
		
		if ( -2 == $next_game_id ) {
			return ( '<h3 class="mstw-lm-user-msg">' . __( 'No games found for specified league(s) & season(s).', 'mstw-league-manager' ) . '</h3>' );
			
		} else if ( -1 == $next_game_id ) {
			// Current time is past last game time, so show as late as possible
			$next_game_number = $nbr_of_games;
			
		}
		
		//
		// Build the HTML
		//
		if ( 'mstw_league_schedule_slider' == $shortcode ) {
			$output = $this -> build_slider_html( $games, $next_game_number, $atts );
			
		} else if ( 'mstw_league_schedule_ticker' == $shortcode ) {
			$output = $this -> build_ticker_html( $games, $next_game_number, $atts );
			
		} else {
			$output = '';
			
		}
		
		return $output;
		
	} //End: build_shortcode( );
	
	//-----------------------------------------------------------------------------
	// build_slider_html - returns the league schedule slider HTML
	// 	
	// ARGUMENTS
	// 	$games  - list of games (objects/CPTs)
	//	$games_to_show - number of games shown in one "slider width"
	//  $game_number - number of game in $games that goes furthest right (visible)
	//  $atts - shortcode arguments (combined with settings)
	//
	// RETURNS
	//	$output - html for the slider
	//
	function build_slider_html( $games, $game_number, $atts ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_slider_html:' );
		//mstw_log_msg( "games:" );
		//mstw_log_msg( $games );
		//mstw_log_msg( "atts:" );
		//mstw_log_msg( $atts );
		
		// This has already been error checked
		$league_slugs = explode( ',', $atts['league'] );
		$css_tag = '_' . $league_slugs[0];
			
		$slider_title = $atts['title'];
		$show_slider_title = ( '' == $slider_title ) ? 0 : 1;
		
		if ( '' == $atts['link'] or '' == $atts['link_label'] ) {
			$show_slider_schedule_link = 0;
			
		} else {
			$show_slider_schedule_link = 1;
			$slider_link = $atts['link'];
			$slider_link_label = $atts['link_label'];
			
		}
		
		$game_block_width = 167;
		
		$nbr_of_games = sizeof( $games );
		
		$game_number = min( $game_number, $nbr_of_games ); //- $games_to_show + 1 );
		
		//container for entire slider
		$output = "\n<div class='lms-slider-container' id='lms-slider-container$css_tag' >\n";
		
			// javascript need the game number
			$output .= "<span class='lms-game-number' id='lms-game-number$css_tag' data-game-number='$game_number' ></span>";
		
			//slider header
			if( $atts['show_header'] ) {
				$output .= "<div class='lms-header' id='lms-header$css_tag'>\n";
					$output .= $this -> build_slider_header( $atts );
				$output .= "</div> <!-- .lms-header --> \n";
			}
			
			// holds the controls, the viewport, and the slider content (game blocks)
			$output .= "<div class='lms-slider-holder'>\n";
			
				//
				// arrow controls - position absolute
				//
				$output .= "<div class='lms-prev' id='lms-prev$css_tag'><p><</p></div>\n";
				
				$output .= "<div class='lms-next' id='lms-next$css_tag'><p>></p></div>\n";
				
				// the 'window' thru which the slider content is visible
				$output .= "<div class='lms-viewport lms-viewport$css_tag'>\n";
					// All slider content ... visible and hidden
					$output .= "<div class='lms-slider-content lms-slider-content$css_tag'>\n";
						$output .= "<ul>\n";
						
							foreach( $games as $game ) {
							//
							// Each list item is a "game block"
							//
							$output .= "<li class=lms-list-item>\n";
							
								$game_status = $this -> getGameStatus( $game, $atts );
								
								$output .= $this -> build_slider_date_line( $atts, $game, $game_status, $css_tag );
								
								$output .= $this -> build_slider_sport_line( $atts, $game );
								
								$output .= $this -> build_slider_team_line( 'away', $game, $game_status, $atts );
								
								$output .= $this -> build_slider_time_status_line( $game, $game_status, $atts );
							
								$output .= $this -> build_slider_team_line( 'home', $game, $game_status, $atts );
								
								$output .= $this -> build_slider_location_line( $game, $atts );
							
							$output .= "</li>\n";
				
				    } 
						
						$output .= "</ul>\n <!--End of games list --> \n";
					$output .= "</div>\n <!--End .lms-slider-content --> \n";
				$output .= "</div>\n <!--End .lms-viewport --> \n";
				
			$output .= "</div>\n <!--End .lms-slider-holder --> \n";
		$output .= "</div> <!--End .lms-slider-container --> \n";
		
		return $output;
		
	} //End: build_slider_html( )
	
	//---------------------------------------------------------------------------
	// build_slider_header
	// 	Builds the league schedule slider header 
	//
	// ARGUMENTS:
	//	$atts - the combined defaults, settings, and shortcode atts
	//
	// RETURNS
	//	Schedule slider content as an HTML string
	//

	function build_slider_header( $atts ) {
		//mstw_log_msg( "build_slider_header:" );
		
		$ret = '';
		
		if( $atts['show_header'] ) {
			$ret .= "<div class=lms-title>\n";
				$ret .= $atts['title'];	
			$ret .= "</div> <!-- .lms-title -->\n";
			
			$ret .= "<div class=lms-link>\n";
				if( '' != $atts['link_label'] ) {
					if( '' != $atts['link'] ) {
						$ret .= "<a href=" . $atts['link'] . " target='_blank'>";
						$ret .= $atts['link_label'] . '</a>';
					}
					else {
						$ret .= $atts['link_label'];
					}
				}
			$ret .= "</div> <!-- .lms-link -->\n"; 
			
			if( $atts['show_message'] ) {
				if ( '' == $atts['message_text'] ) {
					$msg = date( $atts['message_format'], current_time( 'timestamp' ) );
				}
				else {
					$msg = $atts['message_text'];
				}
				$ret .= "<div class=lms-message>$msg</div>";
			}
			
		}
		
		return $ret;
		
	} //End: build_slider_header()
	
	//-----------------------------------------------------------------------------
	// build_ticker_html - returns the league schedule ticker HTML
	// 	
	// ARGUMENTS
	// 	$games  - list of games (objects/CPTs)
	//  $game_number - number of game in $games that goes furthest right (visible)
	//  $atts - shortcode arguments (combined with settings)
	//
	// RETURNS
	//	$output - html for the ticker
	//
	function build_ticker_html( $games, $game_number, $atts ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_ticker_html:' );
		//mstw_log_msg( "games:" );
		//mstw_log_msg( $games );
		//mstw_log_msg( 'atts:' );
		//mstw_log_msg( $atts );
		
		// This has already been error checked
		$league_slugs = explode( ',', $atts['league'] );
		$css_tag = '_' . $league_slugs[0];
		
		// HAS THIS BEEN DONE TO CREATE $GAME_NUMBER *BEFORE* THIS FUNCTION IS CALLED??
		// Figure out the first game visible on the right
		// Already checked that we have games in $games
		$nbr_of_games = sizeof( $games );
		
		//mstw_log_msg( "Orig game_number: $game_number" );
		//mstw_log_msg( "nbr_of_games: $nbr_of_games" );
		
		$game_number = min( $game_number, $nbr_of_games + 1 );
		
		//container for entire ticker
		$output = "\n<div class='lmt-ticker-container' id='lmt-ticker-container$css_tag' >\n";
		
		$output .= "<span class='lmt-game-number' id='lmt-game-number$css_tag' data-game-number='$game_number' ></span>";
			//
			//ticker header is optional
			//
			if( $atts['show_header'] ) {
				$output .= "<div class='lmt-header' id='lmt-header$css_tag'>\n";
				$output .= $this -> build_ticker_header( $atts );
				$output .= "</div> <!-- .lmt-header --> \n";
			}
			
			// holds next and prev buttons and ticker content (game blocks)
			$output .= "<div class='lmt-ticker-holder'>\n";
				//
				// arrow controls - position absolute
				//
				$output .= "<div class='lmt-prev' id='lmt-prev$css_tag'><p><</p></div>\n";
				
				$output .= "<div class='lmt-next' id='lmt-next$css_tag'><p>></p></div>\n";
				
				//
				// Viewport is the "window" through which you can see the ticker tape (the rest is hidden)
				//
				$output .= "<div class='lmt-viewport lmt-viewport$css_tag'>\n"; 
				
					//
					// ticker-content is the entire set of games or the whole "ticker tape"
					//
				  $output .= "<div class='lmt-ticker-content lmt-ticker-content$css_tag'>\n";
						$output  .= "<ul>\n";

				    foreach( $games as $game ) {
							//
							// Each list item is a "game block"
							//
							$output .= "<li class=lmt-list-item>\n";
							//$output .= "<a href='https://calbears.com'>";
							$href = get_site_url( ) . "/" . $game->post_name;
							$output .= "<a href='$href'>";
							
								$game_status = $this -> getGameStatus( $game, $atts );
								
								$output .= $this -> build_ticker_game_header( $atts, $game, $game_status );
							
								$output .= $this -> build_ticker_sport_line( $atts, $game );
							
								$output .= $this -> build_ticker_team_line( 'away', $game, $game_status, $atts );
							
								$output .= $this -> build_ticker_team_line( 'home', $game, $game_status, $atts );
								
							$output .= "</a>";
							$output .= "</li>\n";
				
				    } 
		
				    $output  .= "</ul>\n";
				  $output .= "</div> <!-- .lmt-ticker-content --> \n";
				
				$output .= "</div> <!-- .lmt-ticker-viewport --> \n";
					
			$output .= "</div> <!-- .lmt-holder --> \n";
		
		$output .= "</div> <!-- .lmt-schedule-ticker --> \n";
		
		return $output;
		
	} //End: build_ticker_html
	
	//---------------------------------------------------------------------------
	// build_ticker_header
	// 	Builds the league schedule ticker header 
	//
	// ARGUMENTS:
	//	$atts - the combined defaults, settings, and shortcode atts
	//
	// RETURNS
	//	Schedule ticker content as an HTML string
	//

	function build_ticker_header( $atts ) {
		//mstw_log_msg( "build_ticker_header:" );
		
		$ret = '';
		
		if( $atts['show_header'] ) {
			$ret .= "<div class=lmt-title>\n";
				$ret .= $atts['title'];	
			$ret .= "</div> <!-- .lmt-title -->\n";
			
			$ret .= "<div class=lmt-link>\n";
				if( '' != $atts['link_label'] ) {
					if( '' != $atts['link'] ) {
						$ret .= "<a href=" . $atts['link'] . " target='_blank'>";
						$ret .= $atts['link_label'] . '</a>';
					}
					else {
						$ret .= $atts['link_label'];
					}
				}
			$ret .= "</div> <!-- .lmt-link -->\n"; 
			
			if( $atts['show_message'] ) {
				if ( '' == $atts['message_text'] ) {
					$msg = date( $atts['message_format'], current_time( 'timestamp' ) );
				}
				else {
					$msg = $atts['message_text'];
				}
				$ret .= "<div class=lmt-message>$msg</div>";
			}
			
		}
		
		return $ret;
		
	} //End: build_ticker_header()
	
	
	//---------------------------------------------------------------------------
	// build_ticker_game_header
	// 	Builds the header for the league schedule ticker game block 
	//
	// ARGUMENTS:
	//	$atts - the combined defaults, settings, and shortcode atts
	//  $game - a League Manager game object ( lm_game CPT )
	//	$game_status - array of game status elements ( see getGameStatus( ) )
	//
	// RETURNS
	//	Schedule ticker content as an HTML string
	//
	function build_ticker_game_header( $atts, $game, $game_status ) {
		//mstw_log_msg( "build_ticker_game_header:" );
		
		$ret = "<div class=lmt-game-header> \n";
			$ret .= "<div class='lmt-status'>\n";
				$ret .= "<p class='lmt-status-info'>\n";
			
			// if we are replacing the status, show date or time + replace string
			if ( $game_status['status_replace'] ) {
				if ( date ( 'Ymd', current_time( 'timestamp' ) ) == date ( 'Ymd', $game_status['start_dtg'] ) ) {
						$ret .= date( $atts['time_format'], $game_status['start_dtg'] );	
					} else {
						$ret .= date( $atts['date_format'], $game_status['start_dtg'] );	
					}	
				$ret .= ' ' . $game_status['status_replace'];
			
			} else {
				// If game is final => show "FINAL"
				// If game is in progress (not final but period set) => show period & time
				// If game has not started
				//		if today, show time
				//		else, show date
				//
				
				if( 'is_ppd' == $game_status['status'] ) {
					$ret .= __( 'PPD', 'mstw-league-manager' ) . "&nbsp;&nbsp;" . date( 'd M', $game_status['start_dtg'] );
				
				} else if( 'is_final' == $game_status['status'] ) {
					$ret .= __( 'Final', 'mstw-league-manager' ) . "&nbsp;&nbsp;" . date( 'd M', $game_status['start_dtg'] );
				
				} else if ( 'in_progress' == $game_status['status'] ) {
					$ret .= $this -> numeral_to_ordinal( $game_status['period'] ) . '  ' . $game_status['time_remaining'];
					
				} else if ( 'not_started' == $game_status['status'] ) {
					if ( date ( 'Ymd', current_time( 'timestamp' ) ) == date ( 'Ymd', $game_status['start_dtg'] ) ) {
						$ret .= date( $atts['time_format'], $game_status['start_dtg'] );	
					} else {
						$ret .= date( $atts['date_format'], $game_status['start_dtg'] );	
					}	
				}
				
				// Add link to game page
				// Eventually this should be a new 'ticker_team_link'
				$status_link = array_key_exists( 'schedule_team_link', $atts ) ? $atts['schedule_team_link'] : 'none';
			
				if ( 'team-schedule' == $status_link ) {
						// need team_slug, league_slug, season_slug
						$league_slug = array_key_exists( 'league_slug', $atts  ) ? $atts['league_slug'] : null ;
						$season_slug = array_key_exists( 'season_slug', $atts  ) ? $atts['season_slug'] : null ;
						
						if ( null !== $season_slug and null !== $league_slug ) {
							$link = site_url() . "/league/$league_slug/?season=$season_slug&team=" . $team_obj -> post_name;
							//mstw_lm_log_msg( "link: $link" );
							$ret_str = "<a href = '$link'>$ret</a>";
						}
				}
				
				// Append string, if present
				if ( get_post_meta( $game->ID, 'game_status_append', true ) ) {
					$ret .= " " . get_post_meta( $game->ID, 'game_status_append', true );
				}
				
				// Append Game Name, if present
				if ( get_post_meta( $game->ID, 'game_name', true ) ) {
					$ret .=  "<br/>" . get_post_meta( $game->ID, 'game_name', true );
				}
			
			} //End: if ( $game_status['status_replace'] )
				
			$ret .= "</p>\n"; //Closes <p class='lmt-status-info'
				
			// add the media icon and link if necessary
			$ret .= mstw_lm_build_media_link( $atts, $game, true );
			
			$ret .= "</div><!-- .lmt-status -->";
		$ret .= "</div><!--.lmt-game-header-->\n";		
	
		return $ret;
		
	} //End: build_ticker_game_header()
	
	//---------------------------------------------------------------------------
	// build_media_link - helper function to create the media link HTML, if necessary
	// 	Builds the header for the league schedule ticker game block 
	//
	// ARGUMENTS:
	//	$atts - the combined defaults, settings, and shortcode atts - for future growth
	//  $game - a League Manager game object ( lm_game CPT )
	//
	// RETURNS
	//	The media link as an HTML string, if a media link exists for the game
	//	Otherwise, the empty string
	//
	function build_media_link( $atts, $game ) {
		//mstw_log_msg( "MSTW_LEAGUE_SLIDER_CLASS.build_media_link: " );
		
		$retHTML = '';
		
		if ( $mediaLink = get_post_meta( $game -> ID, 'game_media_link', true ) ) {
			//$videoImageURL = plugin_dir_url( __DIR__ ) . "images/mstw-video-icon.png";
			$videoImageURL = mstw_lm_media_icon_url( );
			//mstw_log_msg( "video image: $videoImageURL" );
			//mstw_log_msg( "media found for game: " . $game -> post_name );
			
			$retHTML = "<a class='lm-media-link' href='$mediaLink' target='_blank' ><img class='lm-media-link' src='$videoImageURL'/></a>";

		} //End if( $mediaLink )
			
		return $retHTML;
		
	} //End: build_media_link( )
	
	//---------------------------------------------------------------------------
	// build_ticker_sport_line
	// 	Builds the header for the league schedule ticker game block 
	//
	// ARGUMENTS:
	//	$atts - the combined defaults, settings, and shortcode atts
	//  $game - a League Manager game object ( lm_game CPT )
	//
	// RETURNS
	//	Schedule ticker content as an HTML string
	//
	function build_ticker_sport_line( $atts, $game ) {
		//mstw_log_msg( "build_ticker_sport_line:" );
		
		$ret = '';
		
		if ( $atts['show_sport'] ) {
			$ret .= "<div class='lmt-sport'>\n";

				$sport_slug = $this -> build_game_sport( $game, false );
				
				$abbrevs = mstw_lm_get_sports_abbrevs( );
				
				$abbrev = ( array_key_exists( $sport_slug, $abbrevs ) ) ? $abbrevs[$sport_slug] : '' ;
				
				$ret .= $abbrev;

			$ret .= "</div>\n";
		}

		return $ret;
		
	} //End: build_ticker_sport_line( )
	
	//-----------------------------------------------------------------------------
	// build_ticker_team_line - returns the HTML for a ticker team line
	// 	
	// ARGUMENTS
	// 	$team - team line identifier home | away
	//	$game  - a game object (mstw_lm_game CPT)
	//	$game_status - array of status_fields (see getGameStatus() )
	//	$atts - shortcode arguments (combined with settings)
	//
	// RETURNS
	//	HTML for the game block
	//
	function build_ticker_team_line( $team = 'home', $game, $status, $atts ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_ticker_team_line:' );
		
		$winner_css = ( $team == $status['is_winner'] ) ? 'winner' : '';
		
		$team_slug = get_post_meta( $game -> ID, "game_{$team}_team", true );
			
		$output = "<div class='team team_$team $winner_css'>";
		
			//
			// show_logos = 0 | 1
			// name_format = short | hide
			// Name must be short format in tickers. It can be hidden if logo is shown.
			//
			if ( $atts['show_logos'] ) {
				$logo_html = mstw_lm_build_team_logo( $team_slug, 'small' );
				$output .= $logo_html;
				
				if ( '' == $logo_html || 'hide' != $atts['name_format'] ) {
					$output .= "<p class='team-name'>";
						$output .= mstw_lm_get_team_name( $game, $team, $atts, 'short' );
					$output .= "</p>\n";
					
				}
				
			} else {  // Not showing logos, so always show short name
				$output .= "<p class='team-name'>";
					$output .= mstw_lm_get_team_name( $game, $team, $atts, 'short' );
				$output .= "</p>\n";
				
			}
			
			
			if ( 'is_final' == $status['status'] || 'in_progress' == $status['status'] && 'is_ppd' != $status['status'] ) {
				$output .= "<p class='team-score'>";
					$output .= $status[ $team . '_score' ];
				$output .= "</p>\n";
				
			}
		
		$output .= "</div> <!--End: .team -->";
		
		return $output;
		
	} //End: build_ticker_team_line( )
	
	//-----------------------------------------------------------------------------
	// build_slider_date_line - returns the HTML for a slider game block's date line
	// 	
	// ARGUMENTS
	// 	$game  - a game object (mstw_lm_game CPT)
	//	$atts - shortcode arguments (combined with settings)
	//	$css_tag - tag uses first league listed in shorcode
	//
	// RETURNS
	//	HTML for the game block's date line
	//
	function build_slider_date_line( $atts, $game, $game_status, $css_tag ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_slider_date_line:' );
		
		// $atts should always have a date_format field, but ...
		$date_format = ( array_key_exists( 'date_format', $atts ) ) ? $atts['date_format'] : 'Y-m-d';
		
		$output = "<div class='lms-date lms-date{$css_tag} lm-pad'>";
			$output .= mstw_date_loc( $date_format, (int)get_post_meta( $game->ID, 'game_unix_dtg', true ) );
		$output .= "</div> <!--end .date-->\n";
	
		return $output;
		
	} //End: build_slider_date_line( ) 
	
	//-----------------------------------------------------------------------------
	// build_slider_sport_line - returns the HTML for a slider game block's sport line
	// 	
	// ARGUMENTS
	// 	$game  - a game object (mstw_lm_game CPT)
	//	$atts - shortcode arguments (combined with settings)
	//
	// RETURNS
	//	HTML for the game block
	//
	function build_slider_sport_line( $atts, $game ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_slider_sport_line:' );
		
		$output = '';
		
		if ( $atts['show_sport'] ) {
			$output .= "<div class='lms-sport'> \n";	
				$output .= $this -> build_game_sport( $game );				
			$output .= "</div> <!--end .lms-sport -->\n";
		}
		
		return $output;
		
	} //End: build_slider_sport_line( )
	
	//-----------------------------------------------------------------------------
	// build_game_sport - convenience function to return a game's sport (name)
	// 	
	// ARGUMENTS
	// 	$game  - a game object (mstw_lm_game CPT)
	//
	// RETURNS
	//	String for league sport
	//
	function build_game_sport ( $game, $name_or_slug = true ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_sport_line:' );
		
		$league_slug = get_post_meta( $game -> ID, 'game_league', true );
		$sport_name = mstw_lm_get_league_sport( $league_slug, $name_or_slug );
		
		return $sport_name;
		
	} //End: build_game_sport( )
	
	//-----------------------------------------------------------------------------
	// build_slider_team_line - returns the HTML for a slider game block's team lines
	// 	
	// ARGUMENTS
	// 	$team - team line identifier home | away
	//	$game  - a game object (mstw_lm_game CPT)
	//	$game_status - array of status_fields (see getGameStatus() )
	//	$atts - shortcode arguments (combined with settings)
	//  $css_tag - css tag to apply to div's ( with leading '_' )
	//
	// RETURNS
	//	HTML for the game block
	//
	function build_slider_team_line( $team = 'home', $game, $status, $atts ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_slider_team_line:' );
		//mstw_log_msg( $atts );
		
		$winner_css = ( $team == $status['is_winner'] ) ? 'winner' : '';
			
		$output = "<div class='team team_$team $winner_css'>";
		
		$team_slug = get_post_meta( $game -> ID, "game_{$team}_team", true );
		
		if ( $atts['show_logos'] ) {
			//get the logo
			$output .= mstw_lm_build_team_logo( $team_slug, 'small' );
		} else {
			$logo = '';
		}
		
		if ( 'hide' == $atts['name_format'] ) {
			$name == '';
			
		} else {
			// Want to pull the format from the $atts eventually
			$output .= "<div class='lms-team-name'>";
				$output .= mstw_lm_get_team_name( $game, $team, $atts, $atts['name_format'] );
			$output .= "</div>\n";
		}
		
		if ( 'is_ppd' != $status['status'] ) {
			if ( '' != $score = get_post_meta( $game -> ID, "game_{$team}_score", true ) ) {
				$output .= "<div class='lms-score'>$score</div>";
				
			} 
		}
		
		$output .= "</div> <!--End: .team -->\n";
		
		return $output;
		
	} //End: build_slider_team_line( )
	
	//-----------------------------------------------------------------------------
	// getGameStatus - returns the game status as an array
	// 	
	// ARGUMENTS
	// 	$game  - a game object (mstw_lm_game CPT)
	//	$atts  - the combined shortcode args and plugin settings
	//
	// RETURNS
	//	game status as array   
	//					'status'         => is_final | not_started | in_progress
	//					'time_is_tba'    => 1 | 0
	//					'start_dtg'      => PHP timestamp
	//					'time_remaining' => string
	//					'period'         => string
	//					'home_score'     => string
	//					'away_score'     => string
	//
	function getGameStatus( $game, $atts ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.getGameStatus:' );
		
		// 
		// Get the game status
		//
		if ( get_post_meta( $game -> ID, 'game_is_ppd', true ) ) {
			$status = 'is_ppd';
		}
		else if ( get_post_meta( $game -> ID, 'game_is_final', true ) ) {
			$status = 'is_final';
		} else if ( '' != get_post_meta( $game -> ID, 'game_period', true ) ) {
			$status = 'in_progress';	
		} else {
			$status = 'not_started';	
		}
		
		//
		// Get the scores
		//
		$home_score = get_post_meta( $game -> ID, 'game_home_score', true );
		
		$away_score = get_post_meta( $game -> ID, 'game_away_score', true );
		
		//
		// If game is final, determine the result
		//	Need to call mstw_lm_is_winner JIC low score wins
		//		
		if ( 'is_final' == $status ) { 
			// game is final, so find the result
			
			// this is for low score wins
			$winner = mstw_safe_get( 'winner', $atts, 'high' );
			
			if ( $home_score == $away_score ) {
				$is_winner = 'tie';
				
			} else if ( mstw_lm_is_winner( 'home', $game, $winner ) ) {
				$is_winner = 'home';
				
			} else {
				$is_winner = 'away';
				
			}
			
			//mstw_log_msg( "winner setting= $winner" );
			//mstw_log_msg( "home score= $home_score away_score= $away_score winner= $is_winner" );
			
		} else {
			// game is not final
			$is_winner = 'none';
			
		}
		
		//
		// Package it up and ship it
		//
		$ret_array = array( 
							'status'         => $status,
							'time_is_tba'    => get_post_meta( $game -> ID, 'game_is_tba', true ),
							'start_dtg'      => get_post_meta( $game -> ID, 'game_unix_dtg', true ),
							'time_remaining' => get_post_meta( $game -> ID, 'game_time_remaining', true ),						
							'period'         => get_post_meta( $game -> ID, 'game_period', true ),
							'home_score'     => $home_score,						
							'away_score'     => $away_score,						
							'is_winner'      => $is_winner,
							'status_replace' => get_post_meta( $game -> ID, 'game_status_replace', true ),
							'status_append'  => get_post_meta( $game -> ID, 'game_status_append', true ),
						  );
		
		return $ret_array;
		
	} //End: getGameStatus( )
	
	//-----------------------------------------------------------------------------
	// build_slider_location_line - returns the HTML for a slider game block's
  //		location line
	// 	
	// ARGUMENTS
	// 	$game  - a game object (mstw_lm_game CPT)
	//	$atts - shortcode arguments (combined with settings)
	//
	// RETURNS
	//	HTML for the game block
	//
	function build_slider_location_line( $game, $atts ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_venue_line:' );
		
		$output = '';
		
		if ( 1 == $atts['show_location'] ) {
			$output = "<div class='location'>\n";
				$output .= mstw_lm_get_game_location( $game, $atts );  
			$output .= "</div> <!--end .location-->\n";
		}
		
		return $output;
		
	} //End: build_venue_line( )
	
	//-----------------------------------------------------------------------------
	// build_slider_time_status_line - returns the HTML for a slider game block's time/result line
	// 	
	// ARGUMENTS
	// 	$game_status  - array of game status fields (See getGameStatus().)
	//	$atts - shortcode arguments (combined with settings)
	//
	// RETURNS
	//	HTML for the game block
	//
	function build_slider_time_status_line( $game, $game_status, $atts ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.build_slider_time_status_line:' );
		//mstw_log_msg( $game_status );
		
		$time_format = mstw_safe_get( 'time_format', $atts, 'H:i' );
		$status = '';
			
		$output = "<div class='time-status'>\n";
			
			// if we are replacing the status, that's it
			if ( $game_status['status_replace'] ) {
				$status = $game_status['status_replace'];
			
			} else {
				if ( 'is_ppd' == $game_status['status'] ) {
				$status = __( 'PPD', 'mstw-league-manager' );
					
				} else if ( 'is_final' == $game_status['status'] ) {
					$status = __( 'FINAL', 'mstw-league-manager' );
					
				} else if ( 'in_progress' == $game_status['status'] ) {
					$period = $period = $this -> numeral_to_ordinal( $game_status['period'] );
					$status = "$period";
					
					if ( '' != $game_status['time_remaining'] ) {
						$time = $game_status['time_remaining'];
						$status = " $time"; 
					}
					
				} else {
					// game has not started, show schedules start time
					$status = date( $time_format, $game_status['start_dtg'] );
					
				} //End: if game status is final
				
				//mstw_log_msg( "slider_status_link" . $atts['slider_status_link'] );
				//mstw_log_msg( $atts );
				// Add link to game page
				// Eventually this should be a new 'slider_time_link'
				if ( array_key_exists( 'slider_status_link', $atts ) ) {
					if ( 'game-page' == $atts['slider_status_link'] ) {
						$href = get_site_url( ) . "/" . $game->post_name;
						$status = "<a href='$href'>$status</a>";
					}	
				}
				
				// Append string, if present
				if ( get_post_meta( $game->ID, 'game_status_append', true ) ) {
					$status .= " " . get_post_meta( $game->ID, 'game_status_append', true );

				}
				
				// Prefix with Game Name, if present
				if ( get_post_meta( $game->ID, 'game_name', true ) ) {
					$status = get_post_meta( $game->ID, 'game_name', true ) . "<br/>" . $status;
				}
				
			} //End: if ( $game_status['status_replace'] ) 
			
			$output .= $status;
			
			//$output .= $this -> build_media_link( $atts, $game );
			$output .= mstw_lm_build_media_link( $atts, $game ); 
			
		$output .= "</div> <!--end .time-status -->\n";
		
		return $output;
		
	} //End: build_slider_time_status_line( )
	
	//-----------------------------------------------------------------------------
	// get_next_game - returns the next game in $games after $time
	// 	
	// ARGUMENTS
	// 	$games  - list of game (objects/CPTs)
	//	$dtg - "current" time as a PHP timestamp
	//
	// RETURNS
	//	$next_game[] array:
	//	  id 
	//		WP ID for next game if found, otherwise
	//		-1 if no game was found with a start DTG after the dtg argument
	//		-2 if $games is empty
	//	  number
	//		position of next game in $games list [ 0 to sizeof($games)-1 ] 
	//		(if found, otherwise see id)
	//	  dtg
	//		PHP time stamp (date-time-group) for next game 
	//		(if found, otherwise see id)
	//
	function get_next_game( $games, $dtg = null ) {
		//mstw_log_msg( 'MSTW_LEAGUE_SCHEDULE_SLIDER.get_next_game:' );
		//mstw_log_msg( $games );
		
		$dtg = ( null === $dtg ) ? current_time( 'timestamp' ) : $dtg;
		
		// No game has been found (yet)
		$next_game = array( 'id' 	  => -1,
						    'number'	  => -1,
						    'dtg'	  => -1,
						  ); 

		// loop thru the game posts to find the first game in the future
		$next_game_number = 0;
		
		if ( $games ) {
			foreach( $games as $game ) {
				// Find first game time after the current time, and (just to be sure) has no result
				if ( get_post_meta( $game->ID, 'game_unix_dtg', true ) > $dtg ) {
					// Ding, ding, ding, we have a winner
					// Grab the data needed and stop looping through the games
					$next_game['id']     = $game->ID;
					$next_game['number'] = $next_game_number;
					$next_game['dtg']    = get_post_meta( $game->ID, 'game_unix_dtg', true );
					break;
				}
				$next_game_number++;
			}
		} else {  
			$next_game['id'] =  -2; 
		}
		
		return $next_game;
		
	} //End: get_next_game( )
	
	//-----------------------------------------------------------------------------
	// numeral_to_ordinal - Converts number to the corresponding ordinal 
	//
	//	ARGUMENTS: 
	//		$nbr - numeral to convert (should be a positive integer)
	//
	//	RETURNS:
	//		Corresponding ordinal as a string
	//
	function numeral_to_ordinal( $nbr ) {
		// no negative numbers allowed
		if ( $nbr < 0 ) {
			$nbr = -$nbr;
		}
		
		// integers oanly
		$nbr = floor( $nbr );
		
		if( 10 < $nbr && $nbr < 20 ) {
			$ret = $nbr . __( 'th', 'mstw-league-manager' );
		}
		else {
			$mod_nbr = $nbr % 10;
			
			switch ( $nbr % 10 ) {
				case 1:
					$ret = $nbr . __( 'st', 'mstw-league-manager' );
					break;
				case 2:
					$ret = $nbr . __( 'nd', 'mstw-league-manager' );
					break;
				case 3:
					$ret = $nbr . __( 'rd', 'mstw-league-manager' );
					break;
				default: // 0,4,5,6,7,8,9
					$ret = $nbr . __( 'th', 'mstw-league-manager' );
					break;				
			}
		}
		
		return $ret;
		
	} //End: numeral_to_ordinal( )
	
	
} //End: class MSTW_LEAGUE_SCHEDULE_SLIDER


//---------------------------------------------------------------------------
// Create an instance of the class, and have the shortcode hander call
// to create the output
//
$league_slider = new MSTW_LEAGUE_SCHEDULE_SLIDER;

add_shortcode( 'mstw_league_schedule_slider', array( $league_slider, 'league_schedule_slider_handler' ) );

add_shortcode( 'mstw_league_schedule_ticker', array( $league_slider, 'league_schedule_slider_handler' ) );