<?php
 /*---------------------------------------------------------------------------
 *	mstw-lm-schedule-table-class.php
 *	Contains the code for the MSTW League Manager multi schedule table
 *		shortcode [mstw_multi_schedule_table]
 *
 *	MSTW Wordpress Plugins (http://shoalsummitsolutions.com)
 *	Copyright 2018-19 Mark O'Donnell (mark@shoalsummitsolutions.com)
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.

 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 *-------------------------------------------------------------------------*/

class MSTW_MULTI_SCHEDULE_TABLE {

	public function __construct( ) {
		add_filter( 'get_multi_schedule_table_instance', [$this, 'get_instance'] );
	}
	
	public function get_instance( ) {
		return $this; //return the object
	}
	
	//---------------------------------------------------------------------------
	// Handles the shortcode inline arguments and merges them with options DB. (settings) 
	// Then creates the multi-schedule table on the user side using those arguments.
	//
	public function shortcode_handler ( $args, $content = null, $shortcode ) {
		//mstw_log_msg( "MSTW_MULTI_SCHEDULE_TABLE.shortcode_handler: shortcode: $shortcode" );
		//mstw_log_msg( "Passed arguments:" );
		//mstw_log_msg( $args );
		//mstw_log_msg( "_POST:" );
		//mstw_log_msg( $_POST );
		
		$leagues = null;
		$sport   = null;
		//
		// check for either a 'leagues' argument or a sport argument
		// if leagues, explode it, and don't check sport
		// if sport, grab all leagues for that sport
		//
		if( array_key_exists( 'leagues', $args ) ) {	
			//mstw_log_msg( $args['leagues'] );
			$leagues = explode( ',', $args['leagues'] );
			
		}
		else if ( array_key_exists( 'sport', $args ) ) {
			$sport_slug = $args['sport'];
			$leagues = mstw_lm_get_leagues_for_sport( $sport_slug );
			mstw_log_msg( );
			
		} else if ( array_key_exists( 'team', $args ) ) {
			mstw_log_msg( "team= {$args['team']}" );
			
		} else {
			return '<h3 class="mstw-lm-user-msg">' . sprintf( __( 'Either a leagues or a sport argument must be passed to the %s shortcode.', 'mstw-league-manager' ), $shortcode ) . '</h3>';
			
		}
		
		$args_str = $this -> create_args_string( $args, array( 'leagues', 'sport' ) );
		
		//mstw_log_msg( $leagues );
		
		$current_league = $this -> set_current_league( $leagues );
		
		$current_season = $this -> set_current_season( $current_league );
		
		//mstw_log_msg( "current_league= $current_league and current_season= $current_season" );
		
		ob_start( );
		?>
		<!-- Still using standings css tags!?! -->
		<form id="multi-league-standings" method="POST" action="">
			<div class="mstw-ms-controls">
				<div class="ms-title">
				<?php _e( 'League:', 'mstw-league-manager' ) ?>
				</div>
				<div class="ms-control">
				<?php mstw_lm_build_league_select( $current_league, $id = 'mst_current_league', true, $leagues ) ?>
				</div>
				
				<div class="ms-title">
				<?php _e( 'Season:', 'mstw-league-manager' ) ?>
				</div>
				<div class="ms-control">
				<?php mstw_lm_build_season_select( $current_league, $current_season, $id = 'mst_current_season' ) ?>
				</div>
			
				<div class="ms-control button">
				<input type="submit" class="secondary" id="lm-mst-submit" name="lm-mst-submit" value='<?php _e( 'Update Schedule Table', 'mstw_league_manager' ) ?>'/>
				</div>
					
			</div> <!-- .mstw-ms-controls --> 
		</form>
		
		<?php 
		echo do_shortcode( "[mstw_league_schedule_table league='$current_league' season='$current_season' $args_str]" ); 
		
		return ob_get_clean();
		
	} //End: shortcode_handler( )
	
	//-----------------------------------------------------------------------------
	// set_current_league - set the current league for the select leagues control
	// 	
	// ARGUMENTS
	//	$leagues - list of leagues
	//
	// RETURNS
	//	The current league, if it is set in #_POST, else the first element of leagues
	//
	function set_current_league( $leagues = null ) {
		//mstw_log_msg( "set_current_league:" );
		//mstw_log_msg( "server request method= " . $_SERVER['REQUEST_METHOD'] );
		//mstw_log_msg( $_POST );
		
		// default return value
		$current_league = null;
		
		if ( 'POST' == $_SERVER['REQUEST_METHOD'] ) {
			if( array_key_exists( 'mst_current_league', $_POST ) ) {
				$current_league = $_POST['mst_current_league'];
			}
			
		} else if ( $leagues ) {
			//$current_league = mstw_lm_get_current_league( );
			$current_league = $leagues[0];
			
		}
		
		return $current_league;
		
	} //End: set_current_league( )
	
	//
	// Convenience function to convert args array passed to shortcode into 
	// args string passed to shortcode
	//
	function create_args_string( $args, $omit = null ) {
		//mstw_log_msg( 'create_args_string:' );
		//mstw_log_msg( $args );
		
		$args_str = '';
		
		foreach ( $args as $key => $value ) {
			if ( !in_array( $key, $omit ) ) {
				$args_str .= " $key='$value' ";
			}
			
		} //End: foreach( $args )
		
		return $args_str;
		
	} //End: create_args_string( )
	
	//-----------------------------------------------------------------------------
	// set_current_season - set the current season for the select season control
	// 	
	// ARGUMENTS
	//	$current_league - selected league in the select league control
	//
	// RETURNS
	//	The season, if it is set in #_POST, else the current season of the current league
	//
	function set_current_season( $current_league = null ) {
		//mstw_log_msg( "set_current_season:" );
		//mstw_log_msg( "server request method= " . $_SERVER['REQUEST_METHOD'] );
		//mstw_log_msg( $_POST );
		
		$current_season = null;
		
		//
		// set the current season
		//
		if ( 'POST' == $_SERVER['REQUEST_METHOD'] ) {
			if( array_key_exists( 'mst_current_season', $_POST ) ) {
				$current_season = $_POST['mst_current_season'];
			}
			
		}	else if ( $current_league ) {
			$current_season = mstw_lm_get_league_current_season( $current_league );
			
		}
		
		return $current_season;
		
	} //End: set_current_season( )

} // End:  class MSTW_MULTI_SCHEDULE_TABLE 

//
// Done with class. Create an instance and add the shortcode
//
$multi_schedule = new MSTW_MULTI_SCHEDULE_TABLE; 

add_shortcode( 'mstw_multi_schedule_table', 
								array( $multi_schedule, 'shortcode_handler' ) );