<?php
 /*---------------------------------------------------------------------------
 *	mstw-lm-standings-table.php
 *	Contains the code for the MSTW League Manager multi standings table
 *		shortcode [mstw_multi_league_standings]
 *
 *	MSTW Wordpress Plugins (http://shoalsummitsolutions.com)
 *	Copyright 2015-19 Mark O'Donnell (mark@shoalsummitsolutions.com)
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.

 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 *-------------------------------------------------------------------------*/

//---------------------------------------------------------------------------
// Add the shortcode handler, which will create the League's Game standings
// table on the user side. Handles the shortcode parameters, if there were 
// any, then calls mstw_lm_build_league_standings( ) to create the output
// 

add_shortcode( 'mstw_multi_league_standings', 'mstw_lm_multi_league_standings' );

//-----------------------------------------------------------------------------
// MSTW_LM_MULTI_LEAGUE_STANDINGS
// 	Builds the html for the multi-league standings table
//
// ARGUMENTS
// 	$args: arguments passed to shortcode (leagues is the only one available )
//
// RETURNS
//	HTML for the standings table for the selected league & schedule, 
//	and the select league and schedule controls.
//
function mstw_lm_multi_league_standings( $args ) {
	//mstw_log_msg( 'mstw_lm_multi_league_standings:' );
	//mstw_log_msg( 'args passed to function' );
	//mstw_log_msg( $args );
	//mstw_log_msg( "_POST:" );
	//mstw_log_msg( $_POST );
	//mstw_log_msg( 'Request method = ' . $_SERVER['REQUEST_METHOD'] );
	
	$args_str = mstw_lm_create_ms_args_string( $args, array( 'leagues' ) );
	//mstw_log_msg( "args as string= $args_str" );
	
	//
	//check for the 'leagues' argument
	//
	if( array_key_exists( 'leagues', $args ) ) {	
		//mstw_log_msg( $args['leagues'] );
		$leagues = explode( ',', $args['leagues'] );
		//mstw_log_msg( $leagues );	
		
	} else {
		$leagues = null;
		
	}
	
	$ret_html = '';
	
	$current_league = null;
	
	//
	// set the current league
	//
	if ( 'POST' == $_SERVER['REQUEST_METHOD'] ) {
		if ( array_key_exists( 'current_league', $_POST ) ) {
			$current_league = $_POST['current_league'];
		}
		
	} else if ( $leagues ) {
		//$current_league = mstw_lm_get_current_league( );
		$current_league = $leagues[0];
		
	}
	
	//
	// set the current season
	//
	$current_season = null;
	
	if ( 'POST' == $_SERVER['REQUEST_METHOD'] ) {
		if ( array_key_exists( 'current_season', $_POST ) ) {
			$current_season = $_POST['current_season'];;
		}
		
	}	else if ( $current_league ) {
			$current_season = mstw_lm_get_league_current_season( $current_league );
			
	}
	
	//mstw_log_msg( "current_league= $current_league and current_season= $current_season" );
	
	ob_start( );
	?>
	
	<form id="multi-league-standings" method="POST" action="">
	  <div class="mstw-ms-controls">
		<div class="ms-title">
		<?php _e( 'League:', 'mstw-league-manager' ) ?>
		</div>
		<div class="ms-control">
		<?php mstw_lm_build_league_select( $current_league, $id = 'current_league', true, $leagues ) ?>
		</div>
			
		<div class="ms-title">
		<?php _e( 'Season:', 'mstw-league-manager' ) ?>
		</div>
		<div class="ms-control">
		<?php mstw_lm_build_season_select( $current_league, $current_season, $id = 'current_season' )?>
		</div>
		
		<div class="ms-control button">
		<input type="submit" class="secondary" id="lm-ml-submit" name="lm-ml-submit" value="Update Standings Table"/>
		</div>
				
	  </div> <!-- .leftalign actions -->
	</form>
	
	<?php echo do_shortcode( "[mstw_league_standings league='$current_league' season='$current_season' $args_str]" ); ?>
	
	<?php 
	return ob_get_clean();

} //End: mstw_lm_multi_league_standings

//
// Convenience function to convert args array passed to shortcode into 
// args string passed to shortcode
//
function mstw_lm_create_ms_args_string( $args, $omit = null ) {
	//mstw_log_msg( 'mstw_lm_create_ms_args_string:' );
	//mstw_log_msg( $args );
	
	$args_str = '';
	
	foreach ( $args as $key => $value ) {
		if ( !in_array( $key, $omit ) ) {
			$args_str .= " $key='$value' ";
		}
		
	} //End: foreach( $args )
	
	return $args_str;
	
} //End: mstw_lm_create_ms_args_string( )

// The action is set in the main plugin file
// add_action( 'init', 'mstw_lm_process_multi_league_standings');

function mstw_lm_process_multi_league_standings( ) {
	//mstw_log_msg( "mstw_lm_process_multi_league_standings:" );
	global $_POST;
	//mstw_log_msg( $_POST );
	//mstw_log_msg( 'Request method = ' . $_SERVER['REQUEST_METHOD'] );
	if ('POST' == $_SERVER['REQUEST_METHOD']) {
		if ( array_key_exists( 'lm-ml-submit', $_POST ) ) {
			$value = stripslashes( $_POST[ 'lm-ml-submit' ] );
			//mstw_log_msg( "mstw_lm_process_multi_league_standings:" );
			//mstw_log_msg( '$_POST:' );
			//mstw_log_msg( $_POST );
			if ( array_key_exists( 'current_league', $_POST ) ) {
				$league_cookie_name = 'mstw-lm-ml-league';
				//mstw_log_msg( 'COOKIEPATH: ' . COOKIEPATH );
				//mstw_log_msg( 'COOKIE_DOMAIN: ' . COOKIE_DOMAIN );
				setcookie( $league_cookie_name, $_POST['current_league'], time() + 30 * DAY_IN_SECONDS, COOKIEPATH, COOKIE_DOMAIN );
			}
			
			if ( array_key_exists( 'current_season', $_POST ) ) {
				$season_cookie_name = 'mstw-lm-ml-season';
				setcookie( $season_cookie_name, $_POST['current_season'], time() + 30 * DAY_IN_SECONDS, COOKIEPATH, COOKIE_DOMAIN );
			}
		}
	}
	
	//exit;
	
} //End: mstw_lm_process_multi_league_standings( )