<?php
 /*---------------------------------------------------------------------------
 *	mstw-lm-standings-table.php
 *	Contains the code for the MSTW League Manager standings table
 *		shortcode [mstw_league_standings]
 *
 *	MSTW Wordpress Plugins (http://shoalsummitsolutions.com)
 *	Copyright 2015-19 Mark O'Donnell (mark@shoalsummitsolutions.com)
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.

 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 *-------------------------------------------------------------------------*/

//---------------------------------------------------------------------------
// Add the shortcode handler, which will create the League's Game standings
// table on the user side. Handles the shortcode parameters, if there were 
// any, then calls mstw_lm_build_league_standings( ) to create the output
// 

add_shortcode( 'mstw_league_standings', 'mstw_lm_shortcode_handler' );

//-----------------------------------------------------------------------------
// MSTW_LM_BUILD_LEAGUE_STANDINGS
// 	Builds the standings table for the specified league & season 
// 	Callback for by mstw_league_standings shorcode. Called from 
//	mstw_lm_shortcode_handler after it has processed the arguments & settings
//
// ARGUMENTS
// 	$atts  - the plugin settings and shortcode arguments; the critical atts are 
//				league and season
//
// RETURNS
//	HTML for schedule table as a string
//
function mstw_lm_build_league_standings( $atts ) {
	//mstw_log_msg( 'mstw_lm_build_league_standings:' );
	//mstw_log_msg( 'attributes passed to function' );
	//mstw_log_msg( $atts );
	
	// Check that we have a league and a season set
	// This is not currently necessary, but it allows for multiple leagues 
	// in the future
	$league_slugs = explode( ',', $atts['league'] );
	//mstw_log_msg( '$league_slugs= ' );
	//mstw_log_msg( $league_slugs );

	// CHECK FOR LEAGUE IN THE ATTRIBUTES; HAVE TO HAVE ONE
	// This is checked by mstw_lm_shortcode_handler as well
	if ( !empty( $league_slugs[0] ) ) {
		//CSS tag will be the FIRST league slug specified
		$css_tag = '_' . $league_slugs[0];
	}
	else {
		//Have to have at least one league slug
		return "<h3 class='mstw-lm-user-msg'>" . __( 'League must be specified in shortcode.', 'mstw-league-manager' ) . '</h3>';
	}
	
	// Check that we have a season set; else default to first season for league
	if ( array_key_exists( 'season', $atts ) && !empty( $atts['season'] ) ) {
		$season_slug = $atts['season'];
		
	} else {
				return "<h3 class='mstw-lm-user-msg'>" . __( 'Season must be specified in shortcode.', 'mstw-league-manager' ) . "</h3>";
				
	}
	
	//mstw_log_msg( '$season_slug= ' . $season_slug );
	
	// Figure out order by to sort properly
	switch ( $atts['order_by'] ) {
		case 'points':
			$sort_key = 'points';
			$sort_order = "DESC";
			break;
			
		case 'rank':
			$sort_key = 'rank';
			$sort_order = "ASC";
			break;
			
		case 'name':
			// This one will require some thought
		case 'percent':
		default:
			$sort_key = 'percent';
			$sort_order = "DESC";
			break;
			
	}
						
	$args = array( 'numberposts'   => -1,
				   'post_type'     => 'mstw_lm_team',
				   'tax_query' => array( 
										array(
											'taxonomy' => 'mstw_lm_league',
											'field'    => 'slug',
											'terms'    => $league_slugs[0],
											),
										),
				   );
				   
	$teams_in_league = get_posts( $args );
	
	$team_slugs = array();
	
	foreach( $teams_in_league as $team ) {
		$team_slugs[] = $team->post_name;
	}
	
	//mstw_log_msg( "teams: " );
	//mstw_log_msg( $team_slugs );
	
	$args = array( 'numberposts'    => -1,
				   'post_type'      => 'mstw_lm_record',
				   
				   'tax_query' => array( 
										array(
											'taxonomy' => 'mstw_lm_league',
											'field'    => 'slug',
											'terms'    => $league_slugs[0],
											),
										),
				   
				  'meta_query' => array(
										
										'relation' => 'AND',
										array( 'key'     => 'team_slug',
											   'value'   => $team_slugs,
											   'compare' => 'IN',
											 ),
											 
										array( 'key'     => 'season_slug',
											   'value'   => $season_slug,
											   'compare' => '=',
											 ),
										),
										
				   'orderby'        => 'meta_value_num',
				   'meta_key'       => $sort_key,
				   'order'          => $sort_order, 
				  ); 
				  
	//mstw_log_msg( $args );
						
	$records = get_posts( $args );
	//mstw_log_msg( '$records: ' . count( $records ) );
	//mstw_log_msg( $records );
	
	if ( $records ) {
		// 
		// New stuff to pull in new features from add-ons
		//
		$resultArray = mstw_lm_calc_fields( $atts, $records );
		//mstw_log_msg( "resultArray:" );
		//mstw_log_msg( $resultArray );
		
		$placeOrder = mstw_lm_init_places( $team_slugs );
		//mstw_log_msg( "placeOrder:" );
		//mstw_log_msg( $placeOrder );
		
		$sortedArray = mstw_lm_sort_standings( $placeOrder, $resultArray, $atts );
		//mstw_log_msg( "sortedArray:" );
		//mstw_log_msg( $sortedArray );
		
		$sortedTeams = array( );
		
		foreach ( $sortedArray as $array ) {
			$sortedTeams[] = $array[ 'team' ];
		}
		//mstw_log_msg( "New sortedTeams:" );
		//mstw_log_msg( $sortedTeams );
		
		
		// Make the standings table
		// Starting with the table header
		$output = "<table class='mstw-lm-table mstw-lm-standings mstw-lm-standings_$league_slugs[0]'>\n"; 
		$output .= "<thead><tr>\n";
			$output .= mstw_lm_build_standings_header( $atts );
		$output .= "</tr></thead>\n";
		
		$output .= "<tbody>\n";
		
		// Loop through the sorted teams and build the table rows
		foreach( $sortedTeams as $team ) {
			$results = $resultArray[ $team ];
			$output .= mstw_lm_build_standings_row_2( $team, $league_slugs[0], $season_slug, $results, $atts );
		}
		
	} else {
		//
		// The $trash strings are here (where they should never be excuted) because they
		// appear in the league manager add-ons standings table
		// (mstw-lmao-standings-table-class.php). It uses the 'mstw-league-manager'
		// text domain, but the add-ons are not in wordpress, so they can't use WP
		// polyglots. 
		//
		$trash = __( 'No games found for league %s in season %s.', 'mstw-league-manager' );
		$trash = __( 'N/A', 'mstw-league-manager' );
		
		return "<h3 class='mstw-lm-user-msg'>" . sprintf( __( 'No records found in league %s', 'mstw-league-manager' ), $league_slugs[0] ) . '.</h3>';
		
	} //End: if ( $records)
	
	$output .= "</tbody></table>\n";
	
	return $output;
	
} //End: mstw_lm_build_league_standings()

//-----------------------------------------------------------------------------
// mstw_lm_calc_fields - builds resultArray from $records array
//	resultArray is in an easily sortable format
//
function mstw_lm_calc_fields( $atts, $records ) {
	//mstw_log_msg( "mstw_lm_calc_fields:" );
	
	$resultArray = array();
	
	foreach ( $records as $record ) {
		$meta = get_post_meta( $record -> ID );
		$team = $meta['team_slug'][0];
		//mstw_log_msg( "found record for team: $team" );
		
		$resultArray[$team]['tGames'] = array( 'w' => $meta['wins'][0],
																					 'l' => $meta['losses'][0],
																					 'd' => $meta['ties'][0],
																					 'otw' => $meta['otw'][0],
																					 'otl' => $meta['otl'][0],
																					 ); 
		
		$resultArray[$team]['tGoals'] = array( 'ga' => $meta['goals_against'][0],
																					 'gf' => $meta['goals_for'][0],
																					 'gd' => $meta['goals_diff'][0],
																					 ); 
																					 
		
		$games = mstw_lm_build_games_array(  $meta['division'][0] );
		$resultArray[$team]['dGames'] = $games;
		$dGP = $games['w'] + $games['l'] + $games['d'];
		$dPts = mstw_lm_calc_pts( $atts, $games );
		$dPct = mstw_lm_calc_pct( $games );
			
		$games = mstw_lm_build_games_array(  $meta['conference'][0] );
		$resultArray[$team]['cGames'] = $games;
		$cGP = $games['w'] + $games['l'] + $games['d'];
		$cPts = mstw_lm_calc_pts( $atts, $games );
		$cPct = mstw_lm_calc_pct( $games );
		
		
		$resultArray[$team]['hGames'] = mstw_lm_build_games_array(  $meta['home'][0] );
		
		$resultArray[$team]['aGames'] = mstw_lm_build_games_array(  $meta['away'][0] );
		
		$resultArray[$team]['standing'] = array( 
																			'tPts' => $meta['points'][0],
																			'cPts' => $cPts,
																			'dPts' => $dPts,
																			'tPct' => $meta['percent'][0],
																			'cPct' => $cPct,
																			'dPct' => $dPct,
																			'tGP'  => $meta['games_played'][0],
																			'cGP'  => $cGP,
																			'dGP'  => $dGP,
																			'rank' => $meta['rank'][0],
																			);
		
		$resultArray[$team]['streak'] = $meta['streak'][0];
		$resultArray[$team]['last_10'] = $meta['last_10'][0];
		$resultArray[$team]['last_5'] = $meta['last_5'][0];                        
		
	}
	
	return $resultArray;
	
} //End: mstw_lm_calc_fields( )

//
// mstw_lm_init_places: initializes & returns an empty places array
//	used to sort the standings as specified by settings after 
//	all calculations are complete
//
function mstw_lm_init_places( $teams ) {
	//mstw_log_msg( "mstw_lm_init_places:");
	
	if ( !$teams ) {
		return array( );
	}
	
	$resultArray = array_fill_keys( $teams, 0 ) ;
	
	//mstw_log_msg( $resultArray );
	
	return $resultArray;
	
} //End: mstw_lm_init_places( )

//
// mstw_lm_sort_standings: sorts & orders the standings based on the $atts:
// 	Primary sort [order_by], 1st tiebreaker [order_by_second], 
//	2nd tiebreaker [order_by_third], and finally alphabetically
//	
//	NOTE: the primary sort (only) will sort high-to-low (DESC) 
//	or low-to-high (ASC) based on the sort order [sort_by]
//
function mstw_lm_sort_standings( $placeOrder, $resultArray, $atts ) {
	//mstw_log_msg( "mstw_lm_sort_standings:" );
	//mstw_log_msg( $resultArray );
	
	$order1 = mstw_safe_get( 'order_by', $atts, 'conf_percent' );
	//$order1 = 'percent'; //test code
	//mstw_log_msg( "first order: $order1" );
	
	$order2 = mstw_safe_get( 'order_by_second', $atts, 'conf_losses' );
	//$order2 = 'conf_losses'; //test code
	//mstw_log_msg( "second order: $order2" );
	
	$order3 = mstw_safe_get( 'order_by_third', $atts, 'conf_wins' );
	//$order3 = 'conf_wins'; //test code order3 in settings defaults but not on admin screen yet
	//mstw_log_msg( 'third order: ' . $order3 );
	
	//
	// the $sortList array is a version of the $resultArray that is suitable for array_multisort
	// 
	$sortlist = array( );
	
	foreach( $resultArray as $team => $results ) {
		$first  = mstw_lm_get_resultfield( $order1, $results, $team );
		$second = mstw_lm_get_resultfield( $order2, $results, $team );
		$third  = mstw_lm_get_resultfield( $order3, $results, $team );
		$last   = mstw_lm_get_resultfield( 'alpha',  $results, $team );
		$sortList[ ] = array( 'team' => $team, 
													'order1' => $first, 
													'order2' => $second, 
													'order3' => $third, 
													'last'   => $last 
												);
	}
	
	//mstw_log_msg( "list to be sorted:" );
	//mstw_log_msg( $sortList );
	
	// sort high to low by default, safeGet( ) is just being safe
	$sort1 = mstw_safe_get( 'sort_by', $atts, 'high_low' );

	$ascDesc1 = ( 'low_high' == $sort1 ) ? SORT_ASC : SORT_DESC;
	$ascDesc2 = ( strpos( $order2, "losses" ) === false ) ? SORT_DESC : SORT_ASC;
	$ascDesc3 = ( strpos( $order3, "losses" ) === false ) ? SORT_DESC : SORT_ASC;
	
	array_multisort( array_column( $sortList, 'order1' ), $ascDesc1, 
									 array_column( $sortList, 'order2' ), $ascDesc2,
									 array_column( $sortList, 'order3' ), $ascDesc3,
									 array_column( $sortList, 'last' ), SORT_ASC,
									 $sortList );								 
	//mstw_log_msg( "Sorted List:" );
	//mstw_log_msg( $sortList );
	
	return $sortList;
	
} //End: mstw_lm_sort_standings( )

//
// mstw_lm_get_resultfield: returns the field from $results specfied by $order
//		NOT TRIVIAL: requires understanding of $results array structure
//
function mstw_lm_get_resultfield( $key, $results, $team ) {
	//mstw_log_msg( "mstw_lm_get_resultfield: ");
	//mstw_log_msg( $results );
	//mstw_log_msg( $key );
	//if ( $team == 'cal-bears' && $key == 'games_played' ) {
		//mstw_log_msg( $results );
	//}
	
	$retVal = 0;
	
	switch ( $key ) {
		case 'games_played':
			$retVal = $results['standing']['tGP'];
			break;
		case 'conf_games_played':
			$retVal = $results['standing']['cGP'];
			break;	
		case 'div_games_played':
			$retVal = $results['standing']['dGP'];
			break;
			
		case 'wins':
			$retVal = $results['tGames']['w'];
			break;
		case 'conf_wins':
			$retVal = $results['cGames']['w'];
			break;
		case 'div_wins':
			$retVal = $results['dGames']['w'];
			break;
		
		case 'losses':
			$retVal = $results['tGames']['l'];
			break;
		case 'conf_losses':
			$retVal = $results['cGames']['l'];
			break;
		case 'div_losses':
			$retVal = $results['dGames']['l'];
			break;
			
		case 'otw':
			$retVal = $results['tgames']['otw'];
			break;
			
		case 'otl':
			$retVal = $results['tgames']['otl'];
			break;
		
		case 'points': // total points
			$retVal = $results['standing']['tPts'];
			break;
		case 'conf_points':
			$retVal = $results['standing']['cPts'];
			break;
		case 'div_points':
			$retVal = $results['standing']['dPts'];
			break;
			
		case 'percent': // total percent
			$retVal = $results['standing']['tPct']; 
			break;
		case 'conf_percent':
			$retVal = $results['standing']['cPct'];
			break;
		case 'div_percent':
			$retVal = $results['standing']['dPct'];
			break;
		
		case 'rank':
			$retVal = $results['standing']['rank'];
			break;
		
		case 'streak':
		case 'otw':
		case 'otl':
		case 'last_5':
		case 'last_10':
			$retVal = $results[ $key ];
			break;
			
		case 'alpha':  // alphanumeric by slug
		default: 
			$retVal = $team;
			break;
	}
	
	$retVal = ( '--' == $retVal ) ? 0 : $retVal;
	
	return $retVal;
	
} //End: mstw_lm_get_resultfield( )

//-----------------------------------------------------------------------------
// mstw_lm_build_games_array - builds an array of games [w][l][d] from a string
//		w-l-d
//
function mstw_lm_build_games_array( $gameStr ) {
	//mstw_log_msg( "mstw_lm_build_games_array: $gameStr" );
	
	$gameArray = array();
	
	$first = strpos( $gameStr, '-' );
	
	if ( false !== $first ) {
		//mstw_log_msg( "got a first for $gameStr" );
		$second = strpos( $gameStr, '-', $first + 1 );
		if ( false !== $second ){
			// second - means theres draws
			//mstw_log_msg( "got a second for $gameStr" );
			//mstw_log_msg( "first= $first" );
			//mstw_log_msg( "second= $second" );
			$gameArray['w'] = substr( $gameStr, 0, $first );
			$gameArray['l'] = substr( $gameStr, $first + 1, $second - $first - 1 );
			$gameArray['d'] = substr( $gameStr, $second + 1 );
			
		} else {
			// no draws
			$gameArray['w'] = substr( $gameStr, 0, $first );
			$gameArray['l'] = substr( $gameStr, $first + 1 );
			$gameArray['d'] = 0;
			
		}
	} else {
		$gameArray['w'] = 0;
		$gameArray['l'] = 0;
		$gameArray['d'] = 0;
	}
	
	$gameArray['otw'] = 0;
	$gameArray['otl'] = 0;
	
	return $gameArray;
	
} //End: mstw_lm_build_games_array( )

//-----------------------------------------------------------------------------
// mstw_lm_calc_pts - helper function to calculate the total points based on 
//		points settings and record
//
function mstw_lm_calc_pts( $atts, $record ) {
	//mstw_log_msg( 'mstw_lm_calc_pts:' );
	//mstw_log_msg( $atts );
	//mstw_log_msg( $atts['points_rules'] );
	//mstw_log_msg( $record );
	
	return $record['w']   * $atts['points_rules']['wins'] +
				 $record['l']   * $atts['points_rules']['losses'] +
				 $record['d']   * $atts['points_rules']['ties'] +
				 $record['otw'] * $atts['points_rules']['otw'] +
				 $record['otl'] * $atts['points_rules']['otl'];
	
} //End: mstw_lm_calc_pts( )

//-----------------------------------------------------------------------------
// mstw_lm_calc_pct - helper function to calculate the total points based on 
//		points settings and record
//
function mstw_lm_calc_pct( $record ) {
	//mstw_log_msg( 'mstw_lm_calc_pct:' );

	$total = $record['w'] + $record['l'] + $record['d'];
	
	if ( $total > 0 ) {
			$percent = ( $record['w'] + 0.5 * $record['d'] ) / $total ;
			
		} else {
			$percent = '--';
			
		}
		
		return $percent;
	
} //End: mstw_lm_calc_pct( )

//-----------------------------------------------------------------------------
// mstw_lm_build_standings_header - returns HTML for standings table header
//
function mstw_lm_build_standings_header( $atts ) {
	//mstw_log_msg( "in mstw_lm_build_standings_header ..." );
	
	// return string
	$output = '';
	
	$fields      = $atts['standings_order'];
	$show_fields = $atts['standings_fields'];
	$labels      = $atts['standings_labels'];
	
	//mstw_log_msg( "Labels:" );
	//mstw_log_msg( $labels );
	
	foreach ( $fields as $field ) {
		if( $show_fields[ $field] ) {
			$output .= '<th>' . $labels[ $field ] . '</th>';
		}
	}
	
	return $output;
	
} //End: mstw_lm_build_standings_header

//-----------------------------------------------------------------------------
// mstw_lm_build_standings_row_2 - returns HTML for one standings table row
//
function mstw_lm_build_standings_row_2( $team_slug, $league_slug, $season_slug, $record, $atts ) {
	//mstw_log_msg( "mstw_lm_build_standings_row_2:" );
	//mstw_log_msg( "league_slug: $league_slug" );
	//mstw_log_msg( "team_slug: $team_slug" );
	//mstw_log_msg( "season_slug: $season_slug" );
	
	// This is a patch for VSN. Weird ...
	$showDraws = mstw_safe_get( 'show_draws', $atts, false );
	//mstw_log_msg( "show_draws= $showDraws" );
	$euroOrder = mstw_safe_get( 'euro_order', $atts, false );
	
	if ( $record ) {
		$fields      = $atts['standings_order'];
		$show_fields = $atts['standings_fields'];
	
		$output = '<tr>';
		
		foreach ( $fields as $field ) { 
			if( $show_fields[ $field ] ) {
				$output .= '<td>';
				switch ( $field ) {
					case 'team':
						if ( $team_slug ) {
							//mstw_log_msg( '$team_slug: ' . $team_slug );
							
							$team = get_page_by_path( $team_slug, OBJECT, 'mstw_lm_team' );
							
							if( $team ) {
								if ( $atts['standings_show_logo'] ) {
									$output .= mstw_lm_build_team_logo( $team->post_name, 'small' );
								}
								$name_format = ( array_key_exists( 'standings_name_format', $atts ) ) 
												 ? $atts['standings_name_format']
												 : 'name';
								$team_link = ( array_key_exists( 'standings_team_link', $atts ) ) 
												 ? $atts['standings_team_link']
												 : 'none';
												 
								$output .= mstw_lm_get_team_name_from_team( $team,$name_format, $team_link, $league_slug, $season_slug );
								
							} // End if ( $team )
							else {
								$output .= __( 'No team object.', 'mstw-league-manager' );
							}
						} //End: if ( $team_id )
						else {
							$output .= __( "No team slug.", 'mstw-league-manager' );
						}
						break;
						
					case 'rank':
						$recStr = ( PHP_INT_MAX == $record['standing']['rank'] ) ? '--' : $record['standing']['rank'];
						$output .= $recStr;
						break;
					
					case 'games_played': //Total games played
						//$output .= $record['tGames']['w'] + $record['tGames']['l'] + $record['tGames']['d'];
						$output .= $record['standing']['tGP'];
						break;
					
					case 'wins': //Total wins
						$output .= $record['tGames']['w'];
						break;
						
					case 'losses': //Total losses
						$output .= $record['tGames']['l'];
						break;
						
					case 'ties': //Total draws
						$output .= $record['tGames']['d'];
						break;
						
					case 'otw':
					case 'otl':
						$output .= $record['tGames'][ $field ];
						break;
						
					case 'wins-losses':
						$output .= mstw_lm_build_wl_record( $record, 't', $showDraws, $euroOrder );
						break;
					
					case 'percent': //Total win %
						$output .= number_format( (float)$record['standing']['tPct'], 3 );
						break;
								
					case 'conf_percent':
						$output .= number_format( (float)$record['standing']['cPct'], 3 );
						break;
						
					case 'div_percent':
						$output .= number_format( (float)$record['standing']['cPct'], 3 );
						break;
						
					case 'points':  //Total points
						$output .= $record['standing']['tPts'];
						break;

					case 'conf_points':
						//$output .= number_format( (float)$record['standing']['cPts'], 3 );
						$output .= $record['standing']['cPts'];
						break;
						
					case 'div_points':
						//$output .= number_format( (float)$record['standing']['cPts'], 3 );
						$output .= $record['standing']['dPts'];
						break;
						
					case 'goals_for':  //Total goals for
						$output .= $record['tGoals']['gf'];
						break;
						
					case 'goals_against': //Total goals against
						$output .= $record['tGoals']['ga'];
						break;
						
					case 'goals_diff': //Goals differential
						//$output .= $record['goals']['gf'] - $record['goals']['ga'];
						$output .= $record['tGoals']['gd'];
						break;
						
					case 'conference':  //Conference record
						$output .= mstw_lm_build_wl_record( $record, 'c', $showDraws, $euroOrder );
						break;
						
					case 'division':  //Division record
						$output .= mstw_lm_build_wl_record( $record, 'd', $showDraws, $euroOrder );
						break;
						
					case 'home':  //Home record
						$output .= mstw_lm_build_wl_record( $record, 'h', $showDraws, $euroOrder );
						break;
								
					case 'away':  //Away record
						$output .= mstw_lm_build_wl_record( $record, 'a', $showDraws, $euroOrder );
						break;						
						
					case 'next_game':
						$slugs = array( $league_slug, $season_slug, $team_slug );
						
						$next_game = mstw_lm_find_next_game( $slugs, null, 0 );
						
						if ( null === $next_game ) {
							$output .= __( '---', 'mstw-league-manager');
							
						} else {
							$output .= mstw_lm_build_next_game( $team_slug, $next_game, $atts );
							
						}
						break;
						
					case 'last_game':
						//mstw_log_msg( "Building last game" );
						
						$slugs = array( $league_slug, $season_slug, $team_slug );
						
						$last_game = mstw_lm_find_last_game( $slugs, null, 0 );
	
						if ( null === $last_game ) {
							$output .= __( '---', 'mstw-league-manager');
							
						} else {
							$output .= mstw_lm_build_last_game( $team_slug, $last_game, $atts );
							
						}
						break;
					
					case 'last_10':
					case 'last_5':
					case 'streak':
					default:
						//$field_tag = 'team_' . $field;
						//mstw_log_msg( 'field_tag = ' . $field_tag );
						$output .= $record[ $field ];
						break;
						
				}
				
				$output .= '</td>';
			}
		}
		$output . '</tr>';
	} //End: if ( $record_obj )
		
	else {
		$output = '';
		mstw_log_msg( 'No record found for: ' . $record->post_name );
	}
	
	return $output;
	
} //End: mstw_lm_build_standings_row_2( )

//-----------------------------------------------------------------------------
// mstw_lm_build_wl_record - helper function returning win-loss-draw record as string
//	$tdcha = 't' for total record, 'c' for conference, 'd' for division
//	includes draws if showDraws == true; displays "w-d-l" if euroOrder = true
//
function mstw_lm_build_wl_record( $record, $tdcha = 't', $showDraws = false, $euroOrder = false ) {
	//mstw_log_msg( "mstw_lm_build_wl_record:" );
	//mstw_log_msg( $record );
	
	//safety check
	$tdcha = ( 'c' == $tdcha || 'd' == $tdcha || 'a' == $tdcha || 'h' == $tdcha ) ? $tdcha : 't' ; 
	
	$games = $tdcha . "Games";
	$w = $record[ $games ][ 'w' ];
	$l = $record[ $games ][ 'l' ];
	$d = $record[ $games ][ 'd' ];
	
	if ( $showDraws ) {
		$retStr = ( $euroOrder ) ? "$w-$d-$l" : "$w-$l-$d" ;
		
	} else {
		$retStr = "$w-$l";
		
	}
	
	return $retStr;
	
} //End: mstw_lm_build_wl_record( )



//-----------------------------------------------------------------------------
// mstw_lm_build_last_game - returns the HTML for the last game column
//	ARGUMENTS:
//		$row_team - slug for team who's row is being built (could be home or away 
//			for the last game)
//		$last_game - mstw_lm_game CPT
//		$atts - combined shortcode args & plugin settings
//
function mstw_lm_build_last_game( $row_team, $last_game = null, $atts ) {
	//mstw_log_msg( "mstw_lm_build_last_game:" );
	//mstw_log_msg( $atts );
	
	$ret_html = '';
	
	if ( null === $last_game ) {
		return '---';
		
	} 
	
	$home_slug = get_post_meta( $last_game->ID, 'game_home_team', true );
	
	$away_slug = get_post_meta( $last_game->ID, 'game_away_team', true );
	
	$short_names = mstw_lm_build_team_short_names( $home_slug, $away_slug );
	
	$home_score = get_post_meta( $last_game->ID, 'game_home_score', true );
	
	$away_score = get_post_meta( $last_game->ID, 'game_away_score', true );
	
	if ( $row_team == $home_slug ) {
		//Row is for home team
		$ret_html = $short_names['away'] . " ";
		
		if ( $home_score != '' and $away_score != '' ) {
			if ( $home_score > $away_score ) {
				 $ret_html .= __( 'W', 'mstw-league-manager' );
				 
			} else if ( $away_score > $home_score ) {
				$ret_html .= __( 'L', 'mstw-league-manager' );
				
			} else {
				$ret_html .= __( 'T', 'mstw-league-manager' );
				
			}
			
			$ret_html .= " $home_score-$away_score";
		}
		
	} else {
		// Row is for away team
		$ret_html = $short_names['home'] . " ";
		
		if ( $home_score != '' and $away_score != '' ) {
			if ( $home_score > $away_score ) {
				 $ret_html .= __( 'L', 'mstw-league-manager' );
				 
			} else if ( $away_score > $home_score ) {
				$ret_html .= __( 'W', 'mstw-league-manager' );
				
			} else {
				$ret_html .= __( 'T', 'mstw-league-manager' );
				
			}
			
			$ret_html .= " $away_score-$home_score";
		}
		
	} //End: if ( $row_team == $home_slug )

	$last_game_link = mstw_safe_get ( 'standings_last_game_link', $atts, 'none' );
	if ( $last_game_link == 'game-page' ) {
		$link = get_site_url( ) . '/lm_game/' . $last_game -> post_name;
		$ret_html = "<a href='$link'>$ret_html</a>";
	}		
	
	return $ret_html;
	
} //End: mstw_lm_build_last_game( )

//-----------------------------------------------------------------------------
// mstw_lm_build_next_game - returns the HTML for the last game column
//	ARGUMENTS:
//		$row_team - slug for team who's row is being built (could be home or away 
//			for the last game)
//		$next_game - mstw_lm_game CPT
//		$atts - combined shortcode args & plugin settings
//
function mstw_lm_build_next_game( $row_team, $next_game = null, $atts ) {
	//mstw_log_msg( "mstw_lm_build_next_game:" );
	
	$next_game_html = ''; //return value
	
	if ( null === $next_game ) {
		return '---';
	} 

	if ( $row_team == get_post_meta( $next_game -> ID, 'game_home_team', true ) ) {
		$next_game_html .= " " . __( 'vs', 'mstw-league-manager' ) . " ";
		$away_team_obj = get_page_by_path( get_post_meta( $next_game -> ID, 'game_away_team', true ), OBJECT, 'mstw_lm_team' );
		$away_team_short_name = get_post_meta( $away_team_obj -> ID, 'team_short_name', true );
		$next_game_html .= $away_team_short_name;
		
	} else {
		$next_game_html .= " " . __( '@', 'mstw-league-manager' ) . " ";
		$home_team_obj = get_page_by_path( get_post_meta( $next_game -> ID, 'game_home_team', true ), OBJECT, 'mstw_lm_team' );
		$home_team_short_name = get_post_meta( $home_team_obj -> ID, 'team_short_name', true );
		$next_game_html .= $home_team_short_name;
		
	}
	
	$next_game_html .= " " . mstw_lm_date_loc( 'D, M j', get_post_meta( $next_game -> ID, 'game_unix_dtg', true ) );
	
	$next_game_link = mstw_safe_get ( 'standings_next_game_link', $atts, 'none' );
	if ( $next_game_link == 'game-page' ) {
		$link = get_site_url( ) . '/lm_game/' . $next_game -> post_name;
		$next_game_html = "<a href='$link'>$next_game_html</a>";
	}

	return $next_game_html;
							
} //End: mstw_lm_build_next_game( )

function mstw_lm_build_team_short_names( $home_slug, $away_slug ) {
	//mstw_log_msg( "mstw_lm_build_team_short_names:" );
	
	if ( $home_slug ) {
		$home_obj = get_page_by_path( $home_slug, OBJECT, 'mstw_lm_team' );
		if ( null !== $home_obj ) {
			$home_name = get_post_meta( $home_obj -> ID, 'team_short_name', true );
			
		} else {
			$home_name = __( 'HOME', 'mstw-league-manager' );
		}
	} else {
		$home_name = __( 'HOME', 'mstw-league-manager' );
	}
	
	if ( $away_slug ) {
		$away_obj = get_page_by_path( $away_slug, OBJECT, "mstw_lm_team" );
		if ( null !== $away_obj ) {
			$away_name = get_post_meta( $away_obj -> ID, 'team_short_name', true );
			
		} else {
			$away_name = __( 'AWAY', 'mstw-league-manager' );
		}
	} else {
		$away_name = __( 'AWAY', 'mstw-league-manager' );
	}
	
	return array( 'home' => $home_name,
				  'away' => $away_name, 
				);
						 
} //End: mstw_lm_build_team_short_names( )

