<?php
/* ------------------------------------------------------------------------
 * 	MSTW League Manager Update Games Class
 *	UI to update all games for a selected league on one screen
 *
 *	MSTW Wordpress Plugins (http://shoalsummitsolutions.com)
 *	Copyright 2015-19 Mark O'Donnell (mark@shoalsummitsolutions.com)
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation, either version 3 of the License, or
 *	(at your option) any later version.

 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 *--------------------------------------------------------------------------*/
 
class MSTW_LM_UPDATE_GAMES {
	
	// For pagination
	const UPDATE_GAMES_ROWS = 20;
	
	private static $data_fields;
	
	function __construct( ) {
		//mstw_log_msg( " MSTW_LM_UPDATE_GAMES.__construct" );
		
		//$options = wp_parse_args( get_option( 'mstw_tr_options' ), mstw_tr_get_defaults( ) );
		
		self::$data_fields = array( 		
						'game_date' => array( __( 'Date', 'mstw-league-manager' ), 16, 32, 1 ),
						'game_time' => array( __( 'Time', 'mstw-league-manager' ), 16, 32, 1 ),
						'game_is_ppd' => array( __( 'Is</br>PPD', 'mstw-league-manager' ), 16, 32, 1 ),
						'game_is_tba' => array( __( 'Time</br>TBA', 'mstw-league-manager' ), 16, 32, 1 ),						
						'game_home_team' => array( __( 'Home</br>Team', 'mstw-league-manager' ), 16, 32, 1 ), 
						'game_home_score' => array( __( 'Home</br>Score', 'mstw-league-manager' ), 3, 32, 1 ),
						'game_away_team' => array( __( 'Away</br>Team', 'mstw-league-manager' ), 16, 32, 1 ), 
						'game_away_score' => array( __( 'Away</br>Score', 'mstw-league-manager' ), 3, 32, 1 ),
						'game_time_remaining' => array( __( 'Time</br>Remaining', 'mstw-league-manager' ), 16, 32, 1 ), 
						'game_period' => array( __( 'Period', 'mstw-league-manager' ), 16, 32, 1 ), 
						//'game_is_open' => array( __( 'Is Open', 'mstw-league-manager' ), 3, 32, 1 ),
						'game_is_final' => array( __( 'Is</br>Final', 'mstw-league-manager' ), 16, 32, 1 ),
						'game_is_conference' => array( __( 'Conf</br>Game', 'mstw-league-manager' ), 16, 32, 1 ),
						'game_is_division' => array( __( 'Div</br>Game', 'mstw-league-manager' ), 16, 32, 1 ),
						'game_media' => array( __( 'Media</br>Label', 'mstw-league-manager' ), 16, 32, 1 ),
						'game_media_link' => array( __( 'Media</br>Link', 'mstw-league-manager' ), 16, 32, 1 ),
						);
						
	} //End __constuct( )
	
	//-------------------------------------------------------------
	//	form - builds the user interface for the Update Games screen
	//-------------------------------------------------------------
	function form( ) {
		//mstw_log_msg( 'in MSTW_LM_UPDATE_GAMES.form ...' );
		?>
		
		<h2><?php _e( 'Update Games', 'mstw-league-manager' )?></h2>
		
		<p class='mstw-lm-admin-instructions'>
		 <?php _e( 'NOTE: YOU MUST CLICK THE UPDATE GAMES BUTTON AT THE BOTTOM OF THE SCREEN TO SAVE ANY CHANGES TO GAMES. Read the contextual help tab on the top right of this screen.', 'mstw-league-manager' ) ?> 
		</p>
		
		<?php
		// Check & cleanup the returned $_POST values
		$submit_value = $this->process_option( 'submit', 0, $_POST, false );
		
		//mstw_log_msg( "submit_value: $submit_value" );
		//mstw_log_msg( 'request method: ' . $_SERVER['REQUEST_METHOD'] );
		//mstw_log_msg( '$_POST =' );
		//mstw_log_msg( $_POST );
		
		//
		// We do the heavy lifting in the post( ) method
		//
		if ('POST' == $_SERVER['REQUEST_METHOD']) {
			$this->post( compact( 'submit_value' ) );
		}

		//
		// Heavy lifting done; now build the HTML UI/form
		//
		mstw_lm_admin_notice( );
			
		$current_league = mstw_lm_get_current_league( );
		//mstw_log_msg( '$current_league: ' . $current_league );
		
		$current_season = mstw_lm_get_league_current_season( $current_league );
		//mstw_log_msg( '$current_season: ' . $current_season );
		
		$current_date = mstw_lm_get_update_games_date( );
		//mstw_log_msg( "current_date: $current_date" );
		
		$current_sport = mstw_lm_get_update_games_sport( );
		//mstw_log_msg( "current_sport: $current_sport" );
		
		// This is used for the DB query and to set the proper CSS
		$button = mstw_safe_get( 'button', $_GET, 'league' );
		
		?>	

		<!-- begin main wrapper for page content -->
		<div class="wrap">
			
		<form id="update-games" class="add:the-list: validate" method="post" enctype="multipart/form-data" action="">
		  <div class="alignleft actions mstw-lm-controls">
		    <?php		 
		    // Select League control
		    $hide_empty = true; // Need a league with at least one team in it
		    $ret = mstw_lm_build_league_select( $current_league, 'main_league', $hide_empty );
		
		    if ( -1 == $ret ) { //No leagues found
					?>
					<ul class='mstw-lm-admin-instructions'>
					<li><?php _e( 'Create a league (with games in it) to use this function.', 'mstw-league-manager' ) ?></li>
					</ul>
					
					<?php
				} else {
					// Select Season control
					$ret = mstw_lm_build_season_select( $current_league, $current_season, 'main_season' );
					
					if ( -1 == $ret ) { //No seasons found for league
						$term_obj = get_term_by( 'slug', $current_league, 'mstw_lm_league', OBJECT, 'raw' );
						if ( $term_obj ) {
							$name = $term_obj->name;
							?>
							<div class='mstw-lm-admin-instructions'><?php printf( __( 'No seasons found for league %s.', 'mstw-league-manager' ), $name ) ?></div>
							<?php
						}
						
					} else {
						$button_css = ( 'league' == $button ) ? 'active' : '' ;
						?>
						<a href="<?php  echo admin_url( 'admin.php?page=mstw-lm-update-games&button=league' )?>" class="button mstw-lm-control-button <?php echo $button_css ?>">
						<?php _e( 'Update Table - League', 'mstw-league-manager' ) ?></a>	
						
						<?php 
						//
						// New date/sport select option in 2.4
						//
						?>
						
						<?php $result = mstw_lm_build_sport_select( $current_sport, 'sport_cntrl' ); ?>
						
						<input type='text' class='date_cntrl' name='date_cntrl' id='date_cntrl' size='10' value='<?php echo $current_date ?>' />
						
						<?php $button_css = ( 'date' == $button ) ? 'active' : '' ; ?>
						<a href="<?php  echo admin_url( 'admin.php?page=mstw-lm-update-games&button=date' )?>" class="button mstw-lm-control-button <?php echo $button_css ?>">
						<?php _e( 'Update Table - Date', 'mstw-league-manager' ) ?></a>
						
					<?php 
					} 
		    } ?>
	    </div> <!-- .leftalign actions -->
			
			<table class='wp-list-table widefat auto striped posts'>
				<?php $this->build_table_header( ); ?>
 			
				<?php
				if ( -1 != $ret ) {
					//mstw_log_msg( "current league: $current_league, current season: $current_season" );
					
					$args = $this -> build_query_args( $button, $current_sport, $current_date, $current_league, $current_season );
					//mstw_log_msg( "args returned from build_query_args:" );
					//mstw_log_msg( $args );
					
					//
					// BUILD GAMES LIST FROM ARGS
					//
					if ( -1 != $current_league &&  !empty( $current_league ) &&
						 -1 != $current_season && !empty( $current_season ) ) {
							 
						$paged = ( array_key_exists( 'paged', $_GET ) ) ? absint( $_GET['paged'] ) : 1;
						
						// $args will be null if there are no leagues for the specified sport
						if ( $args ) {
							$games_list = new WP_Query( $args );
							//$games = $games_list -> posts;
							//mstw_log_msg( 'games:' );
							//mstw_log_msg( $games );
							//mstw_log_msg( self::$data_fields );
							//mstw_log_msg( "count of games_list = " . count( $games_list ) );
							//mstw_log_msg( "count of games_list -> posts = " . count( $games_list -> posts ) );
							
						} else {
							$games_list = null;
							
						}
						
						if ( $games_list && count( $games_list -> posts ) > 0 ) {
							$this->build_table_body( $games_list );
							?>
							<tr> <!-- Submit button -->
								<!--<td colspan="2" class="submit"><input type="submit" class="button" name="submit" value="<?php _e( 'Update Games', 'mstw-league-manager' ); ?>"/></td> -->
								
								<td colspan="2" class="submit tr-action-button">
								<?php submit_button( __( 'Update Games', 'mstw-league-manager' ), 'primary', 'submit' ) ?>
					 
								<td colspan="9"><p class="submit">
								<?php $this -> build_pagination_links( $paged, $games_list -> max_num_pages ); ?>
								</p></td>
							</tr>
							
						<?php 	
						}
						else {
							// No games for league $league
							// Need to adjust message for sport & date
							if ( 'league' == $button ) {
								echo "<tr><td colspan='5'><h3>" . sprintf( __( 'No games found for league %s and season %s.', 'mstw-league-manager' ), $current_league, $current_season ) . "</h3></td></tr>";
							
							} else {
								echo "<tr><td colspan='5'><h3>" . sprintf( __( 'No games found for sport %s and date %s.', 'mstw-league-manager' ), $current_sport, $current_date ) . "</h3></td></tr></p>";
								
							}
						}
					}
					else {
						// A league & season pair or a sport & date pair must be selected
						if ( 'league' == $button ) {
							echo "<h3>" . __( 'Select a league and a season.', 'mstw-league-manager' ) . "</h3>";
						
						} else {
							echo "<h3>" . __( 'Select a sport and a date.', 'mstw-league-manager' ) . "</h3>";
							
						}
					}
				} //End: if ( -1 != $retval )
				?>
			</table> 
		</form>	
		
		</div><!-- end wrap -->
		<!-- end of form HTML -->
		
	<?php
	} //End of function form( )
	
	//-------------------------------------------------------------	
	// build_query_args - builds the WPQuery args based on date, league, and season
	//	ARGS: 
	//		$date: if set, will be used to get games for the date & sport
	//		$sport: will be used to get games for the date & sport, if $date is set
	//		$league: if $date is NOT set, will be used with $season to get games
	//		$season: if $date is NOT set, will be used with $league to get games
	//
	//	RETURNS:
	//		$args: argument array for WPQuery or NULL if no leagues are found for $sport
	//
	function build_query_args( $button = 'league', $sport, $date, $league, $season ) {
		//mstw_log_msg( "MSTW_LM_UPDATE_GAMES.build_query_args:" );
		//mstw_log_msg( "button= $button, sport = $sport, date= $date, league=$league, season=$season" );
		
		$paged = ( array_key_exists( 'paged', $_GET ) ) ? absint( $_GET['paged'] ) : 1;
		//mstw_log_msg( "paged= $paged" );
		
		// get the games in the league
		$args = array( 
					'posts_per_page' => self::UPDATE_GAMES_ROWS,
					'paged'          => $paged,
					'post_type'      => 'mstw_lm_game',
					'post_status'    => 'publish',
					//'mstw_lm_league' => $current_league,
					//'meta_query'     => array( 
					//						'key'     => 'game_season',
					//						'value'   => $current_season,
					//						'compare' => '=',
					//						),
					'meta_key'		=> 'game_unix_dtg',
					'orderby'     => 'meta_value_num',
					'order'       => 'ASC' 
					);
					
		if ( 'date' == $button ) {
			$dtg1 = strtotime( $date );
			$dtg2 = $dtg1 + DAY_IN_SECONDS;
			
			$date_meta_query = array( 'key'     => 'game_unix_dtg',
													 'value'   => array( $dtg1, $dtg2),
													 'type'    => 'numeric',
													 'compare' => 'BETWEEN',
													);
			if ( $sport ) {
				$sport_leagues = mstw_lm_get_leagues_for_sport( $sport );
				//mstw_log_msg( "MSTW_LM_UPDATE_GAMES.build_query_args: sport_leagues=" );
				//mstw_log_msg( $sport_leagues );
				
				if ( $sport_leagues ) {
					$meta_query = array( 'relation' => 'AND',
													array( 'key'  => 'game_league',
																 'value' => $sport_leagues,
																 'compare' => 'IN' )
												);
					$meta_query[] = $date_meta_query;
					
				} else {
					// no leagues found for the specified sport ( for bug in WP_Query meta_query ??)
					return null;
					
				}
				
				//mstw_log_msg( $meta_query );
			
			} else {
				//This should not happen
				$meta_query = $date_meta_query;
				mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.build_query_args: Possible error - $sport is not set.' );
				
			}
													
		} else { //'league' == $button is the default
			$args['mstw_lm_league'] = $league;
			$meta_query = array( 'key'     => 'game_season',
													 'value'   => $season,
													 'compare' => '=',
													);
		}
		
		$args['meta_query'] = $meta_query;
		
		return( $args );
		
		
	} //End: build_query_args( )
	
	//-------------------------------------------------------------	
	// build_table_header - builds the HTML for the update games table header
	// 	  ARGS: 
	//		None. Uses the object's $data_fields private static array
	//	  RETURNS:
	//		None. Outputs the <thead> HTML to the display
	//
	function build_table_header ( ) {
		//mstw_log_msg( "MSTW_LM_UPDATE_GAMES.build_table_header:" );
		
		$data_fields = self::$data_fields;
		//mstw_log_msg( $data_fields );
		?>
		<thead>
		  <tr>
		    <?php
		    foreach ( $data_fields as $data_field ) {
			  $this -> build_table_th( $data_field[0] ); 
		    }
		    ?>
		  </tr>
		</thead>
		<?php		
		
	} //End: build_table_header( )
	
	//-------------------------------------------------------------	
	//  build_table_th - simple utility to wrap string with <th></th>
	// 	  ARGS: 
	//		$games_list - WP_Query object containing the games
	//	  RETURNS:
	//		Outputs $str wrapped with <th></th>
	//
	function build_table_th ( $str ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.build_table_th:' );
		
		echo "<th> $str </th>";
		
	} //End: build_table_th( )
	
	//-------------------------------------------------------------	
	//  build_table_body - builds update games table body
	// 	  ARGS: 
	//		$games_list - WP_Query object containing the games
	//	  RETURNS:
	//		Outputs games table, starting with <tbody>
	//
	function build_table_body ( $games_list ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.build_table_body:' );
		
		$row_nbr = 1;
		
		if ( $games_list -> have_posts( ) ) : 
			?>
			<tbody>
			<?php
			while ( $games_list -> have_posts( ) ):
			
				$games_list -> the_post( );
				
				$game = get_post( get_the_ID( ) );
			
				//mstw_log_msg( "game $row_nbr" );
				//mstw_log_msg( $game );
				
				$this -> build_table_row( $row_nbr, $game );
				
				$row_nbr++;
			
			endwhile;
			?>
			</tbody>
			<?php
		endif;
		
		wp_reset_postdata( );
					
		return;
		
	} //End: build_table_body()
	
	//-------------------------------------------------------------
	//	
	//-------------------------------------------------------------	
	//  build_table_row - creates the HTML for a table row (game) 
	//		in the update games table
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	  RETURNS:
	//		Outputs the row to the screen starting with <tr>
	//
	function build_table_row( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.build_table_row:' );
		//mstw_log_msg( "game $row_nbr" );
		//mstw_log_msg( $game -> post_title );
		//return;
		
		$game_id = $game->ID; //for convenience
		
		?>
		<tr>
		<?php 
		  $this -> game_date_cell( $row_nbr, $game );
		  $this -> game_time_cell( $row_nbr, $game );
			$this -> build_checkbox_cell( $row_nbr, 'game_is_ppd', $game );
		  //$this->is_tba_cell( $row_nbr, $game );
			$this -> build_checkbox_cell( $row_nbr, 'game_is_tba', $game );
		  $this -> team_name_cell( $row_nbr, $game, 'game_home_team' );
		  $this -> team_score_cell( $row_nbr, $game, 'game_home_score' );
		  $this -> team_name_cell( $row_nbr, $game, 'game_away_team' );
		  $this -> team_score_cell( $row_nbr, $game, 'game_away_score' );
		  $this -> time_remaining_cell( $row_nbr, $game );
		  $this -> period_cell( $row_nbr, $game );
		  //$this->is_open_cell( $row_nbr, $game );
		  //$this -> is_final_cell( $row_nbr, $game );
			$this -> build_checkbox_cell( $row_nbr, 'game_is_final', $game );
			//$this -> is_conf_cell( $row_nbr, $game );
			$this -> build_checkbox_cell( $row_nbr, 'game_is_conference', $game );
			//$this->is_div_cell( $row_nbr, $game );
			$this -> build_checkbox_cell( $row_nbr, 'game_is_division', $game );
			$this->media_label_cell( $row_nbr, $game );
			$this->media_link_cell( $row_nbr, $game );
		?>
		</tr>
		
		<?php
		
	} //End: build_table_row()
	
	//-------------------------------------------------------------	
	// build_checkbox_cell - outputs HTML for a checkbox column
	//	ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function build_checkbox_cell( $row_nbr, $field, $game ) {
		//mstw_log_msg( "MSTW_LM_UPDATE_GAMES.build_checkbox_cell: $field" );
		
		$data_fields = self::$data_fields;
		
		if ( array_key_exists( $field, $data_fields ) ) {
			$data = $data_fields[ $field ];
			$field_value = get_post_meta( $game->ID, $field, true );
		} else {
			mstw_log_msg( "field $field not found in data_fields array" );
			$field_value = 0;
		}
		
		//mstw_log_msg ( "field_value= $field_value" );
		
		$checked = checked( 1, $field_value, false );
		
		$css_id = $field . "_" . $game->ID;
		
		echo "<td><input type='checkbox' name=$css_id id=$css_id value='1' $checked /></td>\n";
		
	} //End: build_checkbox_cell( )
	
	//-------------------------------------------------------------	
	// game_date_cell - outputs HTML for the Game Date column
	//	ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function game_date_cell( $row_nbr, $game, $format = 'Y-m-d' ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.game_date_cell:' );
		//echo date( $format, get_post_meta( $game->ID, 'game_unix_dtg', true ) )  
		  
		  $unix_dtg = get_post_meta( $game->ID, 'game_unix_dtg', true );
		  
		  $game_date = date( $format, $unix_dtg );
		
		  $css_id =  'game_date_' . $game->ID;
		
		  echo "<td><input type='text' class='game_date' name=$css_id id=$css_id size='10' value='$game_date' /></td>\n";
		
	} //End: game_date_cell()
	
	//-------------------------------------------------------------	
	//  game_time_cell - ouputs HTML for the Game Time column
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function game_time_cell( $row_nbr, $game, $format = 'H:i' ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.game_date_cell:' );
		//echo date( $format, get_post_meta( $game->ID, 'game_unix_dtg', true ) )  
		  
		$unix_dtg = get_post_meta( $game->ID, 'game_unix_dtg', true );
		  
		$game_time = date( $format, $unix_dtg );
		
		$css_id =  'game_time_' . $game->ID;
		
		echo "<td><input type='text' class='game_time' name=$css_id id=$css_id size='6'  value='$game_time' /></td>\n";
		
	} //End: game_time_cell()
	
	//-------------------------------------------------------------	
	//  team_name_cell - outputs the HTML for Home & Away team columns
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//		$team: team to display game_home_team (default) | game_away_team
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function team_name_cell( $row_nbr, $game, $team = 'game_home_team' ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.team_name_cell:' );
		
		$name = '';
		
		$team_slug = get_post_meta( $game->ID, $team, true );
		//mstw_log_msg( $team_slug );
		
		if ( $team_slug ) {
			$team_obj = get_page_by_path( $team_slug, OBJECT, 'mstw_lm_team' );
			if ( $team_obj ) {
				// This is for teams with school names only
				if ( function_exists( 'lmaoBuildTeamName' ) ) {
					$name = lmaoBuildTeamName( $team_obj );
				} else {
					$name = get_post_meta( $team_obj->ID, 'team_name', true );
				}
			}
		}
		
		echo "<td>$name</td>\n";
		
	} //End: team_name_cell()
	
	//-------------------------------------------------------------	
	//  team_score_cell - outputs HTML for both Home & Away Score columns
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//		$team: team to display game_home_score (default) | game_away_score
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function team_score_cell( $row_nbr, $game, $field = 'game_home_score' ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.team_score_cell:' );
		
		$score = get_post_meta( $game->ID, $field, true );
		
		$css_id =  $field . '_' . $game->ID;
		
		echo "<td><input type='text' name=$css_id id=$css_id size=3 maxlength=16 value='$score' /></td>\n";
		
	} //End: team_score_cell()
	
	//-------------------------------------------------------------	
	//  time_remaining_cell - outputs HTML for the Time Remaining column
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function time_remaining_cell( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.time_remaining_cell:' );

		$time_remaining = get_post_meta( $game->ID, 'game_time_remaining', true );
		
		$css_id = 'game_time_remaining_' . $game->ID;
		
		echo "<td><input type='text' name=$css_id id=$css_id size='5' maxlength = '16' value='$time_remaining' /></td>\n";
		
	} //End: time_remaining_cell()
	
	//-------------------------------------------------------------
	//  period_cell - outputs HTML for the Period column
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function period_cell( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.period_cell:' );

		$period = get_post_meta( $game->ID, 'game_period', true );
		
		$css_id = 'game_period_' . $game->ID;
		
		echo "<td><input type='text' name=$css_id id=$css_id size='3' maxlength = '16' value='$period' /></td>\n";
		
	} //End: period_cell()
	
	//-------------------------------------------------------------
	// media_label_cell - outputs HTML for the Media Label column
	//	ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function media_label_cell( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.media_label_cell:' );

		$media_label = get_post_meta( $game->ID, 'game_media', true );
		
		$css_id = 'game_media_' . $game->ID;
		
		echo "<td><input type='text' name=$css_id id=$css_id size='10' maxlength = '16' value='$media_label' /></td>\n";
		
	} //End: media_label_cell( )
	
	//-------------------------------------------------------------
	// media_link_cell - outputs HTML for the Media Link column
	//	ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function media_link_cell( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.media_link_cell:' );

		$media_link = get_post_meta( $game->ID, 'game_media_link', true );
		
		$css_id = 'game_media_link_' . $game->ID;
		
		echo "<td><input type='text' name=$css_id id=$css_id size='12' maxlength = '64' value='$media_link' /></td>\n";
		
	} //End: media_link_cell( )
	
	//-------------------------------------------------------------	
	//  is_final_cell - ouputs HTML for the Is Final column
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function is_final_cell( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.is_final_cell:' );
		
		$is_final = get_post_meta( $game->ID, 'game_is_final', true );
		
		$checked = checked( 1, $is_final, false );
		
		$css_id = 'game_is_final_' . $game->ID;
		
		echo "<td><input type='checkbox' name=$css_id id=$css_id value='1' $checked /></td>\n";
		
	} //End: is_final_cell()
	
	//-------------------------------------------------------------	
	//  is_conf_cell - ouputs HTML for the Is Conference column
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function is_conf_cell( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.is_conf_cell:' );
		
		$is_conf = get_post_meta( $game->ID, 'game_is_conference', true );
		
		$checked = checked( 1, $is_conf, false );
		
		$css_id = 'game_is_conference_' . $game->ID;
		
		echo "<td><input type='checkbox' name=$css_id id=$css_id value='1' $checked /></td>\n";
		
	} //End: is_conf_cell()
	
	//-------------------------------------------------------------	
	//  is_div_cell - ouputs HTML for the Is Division column
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function is_div_cell( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.is_div_cell:' );
		
		$is_div = get_post_meta( $game->ID, 'game_is_division', true );
		
		$checked = checked( 1, $is_div, false );
		
		$css_id = 'game_is_division_' . $game->ID;
		
		echo "<td><input type='checkbox' name=$css_id id=$css_id value='1' $checked /></td>\n";
		
	} //End: is_div_cell( )
	
	//-------------------------------------------------------------
	//	NOT CALLED CURRENTLY	
	//  is_open_cell - ouputs HTML for the Is Open column
	//	  ARGS: 
	//		$row_nbr: the row's number
	//		$game: a game post (mstw_lm_game)
	//	  RETURNS:
	//		Outputs the table cell to the screen starting with <td>
	//
	function is_open_cell( $row_nbr, $game ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.is_open_cell:' );
		
		$is_open = get_post_meta( $game->ID, 'game_is_open', true );
		
		$checked = checked( 1, $is_open, false );
		
		$css_id = 'game_is_open_' . $game->ID;
		
		echo "<td><input type='checkbox' name=$css_id id=$css_id value='1' $checked /></td>\n";
		
	} //End: is_open_cell()
	
	//-------------------------------------------------------------
	//	build_pagination_links - builds the pagination links html
	//	ARGUMENTS:
	//		$paged: current page number
	//		$max_num_pages: maximum number of pages (in query result)
	//	RETURNS:
	//		Outputs pagination links HTML to display 
	//
	function build_pagination_links( $page, $max_num_pages ) {
		//mstw_log_msg( "MSTW_LM_UPDATE_GAMES.build_pagination_links: " );
					
		$big = 999999999; 
		
		$args = array(
				'base'     => str_replace( $big, '%#%', get_pagenum_link( $big, false ) ),
				'format'   => '?paged=%#%',
				'current'  => $page, //max( 1, get_query_var('paged') ),
				'total'    => $max_num_pages,
				'mid_size' => 2,
				'end_size' => 1,
			);
		
		?>
		<span class="tr-paginate-links">
		  <?php echo paginate_links( $args ); ?>
		</span>
		
	<?php
	} //End: build_pagination_links( )
	
	//-------------------------------------------------------------
	//	set_current_sport - sets the current sport for the Update Games screen
	//	ARGUMENTS:
	//		$sportSlug: current sport slug
	//	RETURNS:
	//		1 on success, 0 on error
	//
	function set_current_sport( $sportSlug ) {
		//mstw_log_msg( "MSTW_LM_UPDATE_GAMES.set_current_sport: " );
		
		return update_option( 'lm-update-games-sport', $sportSlug );
		
	} //End: set_current_sport( )
	
	//-------------------------------------------------------------
	//	get_current_sport - gets the current sport for the Update Games screen
	//	ARGUMENTS:
	//		None
	//	RETURNS:
	//		current sport slug ('' if not found)
	//
	function get_current_sport( ) {
		//mstw_log_msg( "MSTW_LM_UPDATE_GAMES.get_current_sport: " );
		
		return get_option( 'lm-update-games-sport', '' );
		
	} //End: get_current_sport( )
	
	
	//-------------------------------------------------------------
	// post - handles POST submissions - this is the heavy lifting
	//-------------------------------------------------------------------------
	// post - processes posted data from admin form(s) 
	//
	//	ARGUMENTS: 
	//	  $options: option (control) selected, usually a button 
	//	  
	//	  Uses auto global $_POST heavily
	//
	//	RETURNS:
	//	  None. Updates database from $_POST and posts admin messages 
	//	 	to the UI.
	//
	//-------------------------------------------------------------
	function post( $options ) {
		//mstw_log_msg( 'MSTW_LM_UPDATE_GAMES.post:' );
	  //mstw_log_msg( '$options:' );
		//mstw_log_msg( $options );
		//mstw_log_msg( $_FILES );
		//mstw_log_msg( $_POST );

		if ( !$options ) {
			mstw_lm_add_admin_notice( 'error', __( 'Problem encountered. Exiting.', 'mstw-league-manager' ) );
			mstw_log_msg( 'Houston, we have a problem in MSTW League Manger - CSV Import ... no $options' );
			return;
		}
		
		//mstw_log_msg( "Submit value: = " . $options['submit_value'] );
		
		switch( $options['submit_value'] ) {
			case __( 'Select League', 'mstw-league-manager' ):
				//mstw_log_msg( 'post(): Refresh Table ...' );
				//mstw_log_msg( 'Setting option: ' . $_POST['main_league'] );
				mstw_lm_set_current_league( $_POST['main_league'] );
				mstw_lm_set_current_league_season( $_POST['main_league'], $_POST['main_season'] );
				break;
				
			case __( 'Update Games', 'mstw-league-manager' ):
				//mstw_log_msg( 'post(): Update Schedule ...' );
				//return;
				$nbr_fields = count( $_POST ) - 3;
				//mstw_log_msg( "Updating {$nbr_fields} game data fields." );
				
				// Tag indicating a new post_id, or not
				//$last_id = -1;
				
				$games_processed = 0;
				foreach ( $_POST  as $key => $value ) {
					//if ( false !== strpos( $key, 'game_home_score' ) ) {
					if ( false !== strpos( $key, 'game_date' ) ) {
						$games_processed++;
						//mstw_log_msg( 'found new game ' . $games_processed );
						// get the post id
						$last_us = strrchr( $key, '_' );
						//mstw_log_msg( "last underscore string: $last_us" );
						$post_id = substr( $last_us, 1 );
						//mstw_log_msg( "post ID: $post_id" );
						
						//mstw_log_msg( "game_time = " .  $_POST[ 'game_unix_dtg_' . $post_id ] );
						
						$game_dtg = $_POST[ 'game_date_' . $post_id ];
						//mstw_log_msg( "game_date = $game_dtg" );
						//mstw_log_msg( "ctype_space= " . ctype_space( $game_dtg ) );
						if ( $game_dtg == '' || ctype_space( $game_dtg ) ) {
							$game_dtg = "1970-01-01";
						}
						//mstw_log_msg( "game_date = $game_dtg" );
						
						if ( array_key_exists( 'game_time_' . $post_id, $_POST ) ) {
							$game_dtg .= ' ' . $_POST[ 'game_time_' . $post_id ];
						}
						
						//mstw_log_msg( "game_dtg = $game_dtg" );
						
						$game_unix_dtg = strtotime( $game_dtg ); 
						//mstw_log_msg( "unix_dtg = $game_unix_dtg" );
						//mstw_log_msg( date( 'Y-m-d H:i', $game_unix_dtg ) );
						
						update_post_meta( $post_id, 'game_unix_dtg', $game_unix_dtg );
						
						$game_is_tba = ( array_key_exists( 'game_is_tba_' . $post_id, $_POST ) ) ? 1 : 0;
						//mstw_log_msg( "game is TBA= " . $game_is_tba );
						update_post_meta( $post_id, 'game_is_tba', $game_is_tba );
						
						if ( array_key_exists( 'game_home_score_' . $post_id, $_POST ) ) {
							$game_home_score = $_POST[ 'game_home_score_' . $post_id ]; 
							//mstw_log_msg( "home_score= $game_home_score" );
							update_post_meta( $post_id, 'game_home_score', $game_home_score );
						}
					
						if ( array_key_exists( 'game_away_score_' . $post_id, $_POST ) ) {
							$game_away_score = $_POST['game_away_score_' . $post_id ];
							//mstw_log_msg( "away_score= " . $game_away_score );
							update_post_meta( $post_id, 'game_away_score', $game_away_score );
						}
						
						if ( array_key_exists( 'game_time_remaining_' . $post_id, $_POST ) ) {
							$game_time_remaining = $_POST['game_time_remaining_' . $post_id ];
							//mstw_log_msg( "time remaining= " . $game_time_remaining );
							update_post_meta( $post_id, 'game_time_remaining', $game_time_remaining );
						}
						
						if ( array_key_exists( 'game_period_' . $post_id, $_POST ) ) {
							$game_period = $_POST['game_period_' . $post_id ];
							//mstw_log_msg( "period= " . $game_period );
							update_post_meta( $post_id, 'game_period', $game_period );
						}
						
						$game_is_ppd = ( array_key_exists( 'game_is_ppd_' . $post_id, $_POST ) ) ? 1 : 0;
						//mstw_log_msg( "game is ppd= " . $game_is_ppd );
						update_post_meta( $post_id, 'game_is_ppd', $game_is_ppd );
						
						$game_is_final = ( array_key_exists( 'game_is_final_' . $post_id, $_POST ) ) ? 1 : 0;
						//mstw_log_msg( "game is final= " . $game_is_final );
						update_post_meta( $post_id, 'game_is_final', $game_is_final );
						
						// If game is final it can't be open
						if ( 1 == $game_is_final ) {
							$game_is_open = 0;
							update_post_meta( $post_id, 'game_is_open', 0 );
						}
						else { // Otherwise deal with the game is open field
							$game_open_field = 'game_is_open';
							$game_open_key = 'game_is_open_' . $post_id;
							$game_is_open = ( array_key_exists( $game_open_key, $_POST ) ) ? 1 : 0;
							update_post_meta( $post_id, $game_open_field, $game_is_open );
						}
						//mstw_log_msg( "game is open= " . $game_is_open );
						
						$is_conf = ( array_key_exists( 'game_is_conference_' . $post_id, $_POST ) ) ? 1 : 0;
						//mstw_log_msg( "game is conference= " . $is_conf );
						update_post_meta( $post_id, 'game_is_conference', $is_conf );
						
						$is_div = ( array_key_exists( 'game_is_division_' . $post_id, $_POST ) ) ? 1 : 0;
						//mstw_log_msg( "game is division= " . $is_div );
						update_post_meta( $post_id, 'game_is_division', $is_div );
						
						if ( array_key_exists( 'game_media_' . $post_id, $_POST ) ) {
							$game_media = $_POST['game_media_' . $post_id ];
							//mstw_log_msg( "media label= " . $game_media );
							update_post_meta( $post_id, 'game_media', $game_media );
						}
						
						if ( array_key_exists( 'game_media_link_' . $post_id, $_POST ) ) {
							$game_media_link = $_POST['game_media_link_' . $post_id ];
							//mstw_log_msg( "media link= " . $game_media_link );
							update_post_meta( $post_id, 'game_media_link', $game_media_link );
						}
						
					} //End: if ( false !== strpos( $key, 'game_unix_dtg' ) ) {	
					
				} //End: foreach ( $_POST  as $key => $value ) {
			
				mstw_lm_add_admin_notice( 'updated', sprintf( __( 'Updated %s games.', 'mstw-league-manager' ), $games_processed ) );
				
				break;
				
			default:
				//$this->log['notice'][] = sprintf( __( 'No function found for %s.)', 'mstw-league-manager' ), $options['submit_value'] );
				mstw_log_msg( 'Error encountered in post() method. $submit_value = ' . $submit_value . '. Exiting' );
				return;
				break;
		}
			
	} //End: post( )
	
	//-------------------------------------------------------------
	// process_option - checks/cleans up the $_POST values
	//-------------------------------------------------------------
	function process_option( $name, $default, $params, $is_checkbox ) {
		//mstw_log_msg( "process_option:" );
		//mstw_log_msg( "name = $name" );
		//mstw_log_msg( "default = $default" );
		//mstw_log_msg( "is_checkbox = $is_checkbox" );
		//mstw_log_msg( "params:" );
		//mstw_log_msg( $params );
		
		//checkboxes which if unchecked do not return values in $_POST
		if ( $is_checkbox and !array_key_exists( $name, $params ) ) {
			$params[ $name ] = $default;	
		}
		
		if ( array_key_exists( $name, $params ) ) {
			$value = stripslashes( $params[ $name ] );
			
		} elseif ( $is_checkbox ) {
			//deal with unchecked checkbox value
		
		} else {
			$value = null;
		}
		
		return $value;
		
	} //End function process_option()

	
    //-------------------------------------------------------------
	// add help - outputs HTML for the contextual help area of the screen
	//		
	// ARGUMENTS:
	//	 None 
	//   
	// RETURNS:
	//	 Outputs HTML to the contextual help area of the screen
	//-------------------------------------------------------------
	
	function add_help( ) {
		//mstw_log_msg( "in update games add_help" );
		
		$screen = get_current_screen( );
		// We are on the correct screen because we take advantage of the
		// load-* action ( in mstw-lm-admin.php, mstw_lm_admin_menu()
		
		mstw_lm_help_sidebar( $screen );
		
		$tabs = array( array(
						'title'    => __( 'Overview', 'mstw-league-manager' ),
						'id'       => 'update-games-overview',
						'callback'  => array( $this, 'add_help_tab' ),
						),
					 );
					 
		foreach( $tabs as $tab ) {
			$screen->add_help_tab( $tab );
		}
		
	} //End: add_help( )
	
	function add_help_tab( $screen, $tab ) {
		//mstw_log_msg( "in update games add_help_tab ... " );
		
		if( !array_key_exists( 'id', $tab ) ) {
			return;
		}
			
		switch ( $tab['id'] ) {
			case 'update-games-overview':
				?>
				<p><?php _e( 'This screen allows updating the status of the games for a league and season OR on a specified day.', 'mstw-league-manager' ) ?></p>
				<p><?php _e( 'Either select a LEAGUE and SEASON in the controls, then press the Update Table - League button, OR select a SPORT and DATE, then press Update Table - Date. NOTE: these buttons will NOT make changes to the database.', 'mstw-league-manager' ) ?></p>
				<p><?php _e( 'Enter updated information for games, as necessary.', 'mstw-league-manager' ) ?></p>
				<p><?php _e( 'Click the Update Games button at the bottom of the screen to save your changes to the database.', 'mstw-league-manager' ) ?></p>
				
				<p><a href="//shoalsummitsolutions.com/lm-update-games/" target="_blank"><?php _e( 'See the Update Games man page for more details.', 'mstw-league-manager' ) ?></a></p>
				<?php
				
				break;
			
			default:
				break;
		} //End: switch ( $tab['id'] )

	} //End: add_help_tab()
	
} //End: class MSTW_LM_UPDATE_GAMES
?>